function [ah,mu_c,ac,rp,mu_f,mu_c_neg,mu_f_neg] = fn_plot_backbone(fy,deltay,ah,mu_c,ac,rp,mu_f,fy_neg,mu_c_neg,mu_f_neg,flag,sig,flag_fo_bil)

% Function fn_plotread2
%-------------------------------------
% DESCRIPTION:
% the function allows plotting all types of linearized curve 
% 
%-------------------------------------
% INPUT:
%-------------------------------------

% fy:         yield strength;
% deltay:     yield displacement;
% ah:         ratio between hardening slope and elastic slope;
% mu_c:       mu at the end of hardening slope; 
% ac:         ratio between negative (capping) slope and elastic slope;
% rp:         Residual plateau height, a fraction of Fy;
% mu_f:       fracturing mu (deltay * mu_f is the end of SPO);
% fy_neg:     Negative yield strength;
% mu_c_neg:   Negative mu at the end of hardening slope; 
% mu_f_neg:   Negative fracturing mu (deltay * mu_f is the end of SPO);
% flag:       1 per plot mu-R, 2 per plot d-V
% sig:        0 plot negative backbone too, 10 plot only negative!
% flag_fo_bil: Flag for bilinear backbone
%-------------------------------------
% OUTPUT:
%-------------------------------------
% [dl,Fl]:    Linearized curve. dl is displacement vector, Fl is force
% vector
if nargin<13
    flag_fo_bil=0;
end
if isempty(flag_fo_bil)
    flag_fo_bil=0;
end

    fy=abs(fy);
    deltay=abs(deltay);
    ah=abs(ah);
    mu_c=abs(mu_c);
    ac=abs(ac);
    rp=abs(rp);
    mu_f=abs(mu_f);
%     fy_neg=abs(fy_neg);
    if rp>1
        rp=1;
    end
if sig~=0
    if (abs(fy)>0.99*abs(fy_neg) & abs(fy)<1.01*abs(fy_neg)) & abs(mu_c)==abs(mu_c_neg) & abs(mu_f)==abs(mu_f_neg)
        sig=1;
    else
        sig=0;
    end
end
%%%
F(1)=0;
d(1)=0;
%%%
F(2)=1;
d(2)=1;
if flag_fo_bil==0
%%%
        d(3)=mu_c;
        F(3)=ah*(mu_c-1)+1;

        if isempty(rp) || rp<0.00000001 & rp>-0.00000001 
            if ~isempty(ac) & ac~=0 & mu_f>=((ac*mu_c+F(3))/ac)
                d(4)=(ac*mu_c+F(3))/ac;
                F(4)=0;      
                mu_f=d(4);
            elseif ~isempty(ac) & ac~=0 & mu_f<((ac*mu_c+F(3))/ac)
                d(4)=mu_f;
                d(5)=mu_f;
                F(4)=-ac*(mu_f-mu_c)+F(3);      
                F(5)=0;
            elseif ~isempty(ac) & ac==0
                mu_c=mu_f;
                d(3)=mu_f;
                d(4)=mu_f;
                F(4)=F(3); 
            else      
                d(4)=mu_f;
                F(4)=0;
                ac=F(3)/(mu_f-mu_c);
            end
        else
            %%%
            d(4)=(F(3)-rp)/(ac)+mu_c;
            if d(4)<=mu_f
                    F(4)=rp;
                    %%%
                    d(5)=mu_f;
                    F(5)=F(4);
                    %%%
                    d(6)=mu_f;
                    F(6)=0;
                    if isequal((d(4)-d(5)),0)
                        errordlg('Backbone parameters are not compatible with each other, please check data','Error');
                        error('Backbone parameters are not compatible with each other')
                    end
            else
                d(4)=mu_f;
                F(4)=-ac*(mu_f-d(3))+F(3);
                d(5)=d(4);
                F(5)=0;
                rp=0;
            end
 
        end
else
        d(3)=10^5;
        F(3)=ah*(d(3)-1)+1;
end
if flag==2
    plot(deltay.*d,fy.*F,'color','k','linewidth',3);hold on;box on;hold on; grid on;hold off;
    hold on
    plot(deltay.*d,fy.*F,'o','MarkerEdgeColor','k',...
    'MarkerFaceColor','r')
    xlabel('Displacement (m)','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    ylabel('Strength (kN)','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    if flag_fo_bil==0
        xlim([0 1.1*deltay.*d(end)])
        ylim([0 1.1*fy.*max(F)])
    else
        xlim([0 1.1*deltay*22])
        ylim([0 1.1*fy.*(ah*(1.1*22-1)+1)])
    end
    
else
    plot(d,F,'color','k','linewidth',3);hold on;box on;hold on; grid on;hold off;
    hold on
    plot(d,F,'o','MarkerEdgeColor','k',...
    'MarkerFaceColor','r')
    xlabel('\mu','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    ylabel('R','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    if flag_fo_bil==0
        xlim([0 d(end)+1])
        ylim([0 0.1+max(F)])
    else
        xlim([0 d(2)*22])
        ylim([0 1.1+(ah*(d(2)*22-1))])
    end
   
end
[d1,F1,mu_c_neg,mu_f_neg]=fn_negative_back(ah,mu_c,ac,rp,mu_f,mu_c_neg,mu_f_neg,flag_fo_bil,d,F);
if sig==0
    if flag==2
    hold on
     plot((fy_neg/(fy/deltay)).*d1,fy_neg.*F1,'color','k','linewidth',3);hold on;box on;hold on; grid on;hold off;
    hold on
    plot((fy_neg/(fy/deltay)).*d1,fy_neg.*F1,'o','MarkerEdgeColor','k',...
            'MarkerFaceColor','r')
    xlabel('Displacement (m)','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    ylabel('Strength (kN)','FontWeight','normal','FontSize',10,'FontName','Times New Roman')     
    else
        hold on
     plot(-d1,-F1,'color','k','linewidth',3);hold on;box on;hold on; grid on;hold off;
    hold on
    plot(-d1,-F1,'o','MarkerEdgeColor','k',...
            'MarkerFaceColor','r')   
    xlabel('\mu','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    ylabel('R','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
    end
    LineH = get(gca, 'children');
    Value = get(LineH, 'YData');
    Valuex = get(LineH, 'XData');
    if flag_fo_bil==0
        xlim([min(Valuex{1})*1.1,max(Valuex{3})*1.1])
        ylim([min(Value{1})*1.1,max(Value{3})*1.1])
    else
        xlim([Valuex{1}(2)*20,Valuex{3}(2)*20])
        ylim([Value{1}(2)*(ah*(1.1*20-1)+1)*1.1,Value{3}(2)*(ah*(1.1*20-1)+1)*1.1])
    end
    
elseif sig==10
    cla(gca)
    if flag==2
        plot((fy_neg/(fy/deltay)).*d1,fy_neg.*F1,'color','k','linewidth',3);hold on;box on;hold on; grid on;hold off;
        hold on
        plot((fy_neg/(fy/deltay)).*d1,fy_neg.*F1,'o','MarkerEdgeColor','k',...
        'MarkerFaceColor','r')
        xlabel('Displacement (m)','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
        ylabel('Strength (kN)','FontWeight','normal','FontSize',10,'FontName','Times New Roman')

    else
        plot(-d1,-F1,'color','k','linewidth',3);hold on;box on;hold on; grid on;hold off;
        hold on
        plot(-d1,-F1,'o','MarkerEdgeColor','k',...
        'MarkerFaceColor','r')
        xlabel('\mu','FontWeight','normal','FontSize',10,'FontName','Times New Roman')
        ylabel('R','FontWeight','normal','FontSize',10,'FontName','Times New Roman')

    end
LineH = get(gca, 'children');
Value = get(LineH, 'YData');
Valuex = get(LineH, 'XData');
if flag_fo_bil==1
    xlim([Valuex{1}(2)*20,0])
else
    xlim([(Valuex{1})*1.1,0])
end
ylim([min(Value{1})*1.1,0])  
end
grid on
set(gca,'fontsize',10)
