 function [EDP_matrix_mod]=fn_checkEDP_MSA(EDP_matrix,duct,delta_y,Fy,duct_neg,Fy_neg)
% Function fn_checkEDP_MSA
%-------------------------------------
% DESCRIPTION:
% the function checks if in the EDP matrix get by MSA some value exceeds
% limit imposed by ductility
% 
%-------------------------------------
% INPUT:
%-------------------------------------
% pwd_opening: path where main GUI is located
% EDP_matrix:  Matrix containing EDP stripes;
% duct:        ductility mu_f from backbone;
% delta_y:     Yielding displacement;
% Fy:          Yielding force;
% duct_neg:    ductility mu_f from backbone (negative);
% delta_y_neg: Yielding displacement (negative)
%-------------------------------------
% OUTPUT:
%-------------------------------------
% EDP_matrix_mod:  Modified EDP matrix;
if nargin<4
    duct_neg=duct;
    Fy_neg=-Fy;
end
delta_y_neg=(abs(Fy_neg)/Fy)*delta_y;
EDP_limduc=zeros(length(EDP_matrix(:,1)),length(EDP_matrix(1,:)));
% Check if the maximum value occurs in + or - direction:
check=(EDP_matrix>0);
EDP_limduc(check)=duct*delta_y;
EDP_limduc(check==0)=duct_neg*delta_y_neg;
% Find if some EDP exceeds limit:
ind_=abs(EDP_matrix)>EDP_limduc;
% Replace exceedence with nan
EDP_matrix_mod=abs(EDP_matrix);
EDP_matrix_mod(ind_==1)=nan;



