function [dvalues_act,dlabel]=fn_check_EDP_IM_MSA(msa,EDP_flag,Disp_lim,flag_no_sc)   
% check_EDP_IM_MSA
%-------------------------------------
% DESCRIPTION:
% In the modified IDA structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% ida:            MSA structure from trace_IDA
% EDP_flag:       1 for disp max_x, 2 for disp_max_y, 3 for max_res_x, 4
%                 for max_res_y, 5 for max disp along 2 dir, 6 for max residual disp
%                 along 2 direction, 7 for quadratic combination between displacements,
%                 8 for quadratic combination between residual disp
% Disp_lim:       Limit for D/C. It is a vector for x and y combination
%                 while it is a scalar value for x and y individually
% flag_no_sc:  If it is = 1 a Cloud analysis has been performed, so
%              structure is not a matrix but a vector (EDP,IM)
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% dvalues_act:    results from traceIDA for MSA, active EDP 
% dlabel:         String for x label in EDP-IM plot
%--------------------------------------------------------------------------
if nargin<4
    flag_no_sc=0;
end
if nargin<3
    Disp_lim=[];
    flag_no_sc=0;
end
if EDP_flag>8 & isempty(Disp_lim)
    h=warndlg('Set a capacity limit!','Warning');
    warning('Set a capacity limit!');
    waitfor(h)
    return
end

if flag_no_sc~=1
    if  EDP_flag==1
       dvalues_act=msa.EDP_d_x;  
    elseif  EDP_flag==2
        dvalues_act=msa.EDP_d_y;
    elseif  EDP_flag==3
        dvalues_act=msa.EDP_res_x;
    elseif  EDP_flag==4
        dvalues_act=msa.EDP_res_y;
    elseif  EDP_flag==5
        dvalues_act=msa.EDP_d_max;
    elseif  EDP_flag==6
        dvalues_act=msa.EDP_res_max;
    elseif  EDP_flag==7
        dvalues_act=msa.EDP_d_quadmax;
    elseif  EDP_flag==8
        dvalues_act=msa.EDP_res_quad;
    elseif  EDP_flag==9
                dvalues_act=msa.EDP_d_x/Disp_lim(1);      
    elseif  EDP_flag==10
                dvalues_act=msa.EDP_d_y/Disp_lim(1);  
    elseif  EDP_flag==11
                dvalues_act=msa.EDP_res_x/Disp_lim(1);  
    elseif  EDP_flag==12
                dvalues_act=msa.EDP_res_y/Disp_lim(1);  
    elseif  EDP_flag==13
                dvalues_x_D_C=msa.EDP_d_x/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_d_y/Disp_lim(2);
                dvalues_x_D_C(find(isnan(dvalues_x_D_C)))=inf;
                dvalues_y_D_C(find(isnan(dvalues_y_D_C)))=inf;
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);

    elseif  EDP_flag==14
                dvalues_x_D_C=msa.EDP_res_x/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_res_y/Disp_lim(2);
                dvalues_x_D_C(find(isnan(dvalues_x_D_C)))=inf;
                dvalues_y_D_C(find(isnan(dvalues_y_D_C)))=inf;
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==15
                dvalues_x_D_C=msa.EDP_d_x/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_d_y/Disp_lim(2);
                dvalues_x_D_C(find(isnan(dvalues_x_D_C)))=inf;
                dvalues_y_D_C(find(isnan(dvalues_y_D_C)))=inf;
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
    elseif  EDP_flag==16
                dvalues_x_D_C=msa.EDP_res_x/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_res_y/Disp_lim(2);
                dvalues_x_D_C(find(isnan(dvalues_x_D_C)))=inf;
                dvalues_y_D_C(find(isnan(dvalues_y_D_C)))=inf;
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
    else
        dvalues_act=msa.EDP_d_x;
    end
    dvalues_act(find(isinf(dvalues_act)))=nan;  
else
    if  EDP_flag==1
       dvalues_act=msa.EDP_d_x_cl;  
    elseif  EDP_flag==2
        dvalues_act=msa.EDP_d_y_cl;
    elseif  EDP_flag==3
        dvalues_act=msa.EDP_res_x_cl;
    elseif  EDP_flag==4
        dvalues_act=msa.EDP_res_y_cl;
    elseif  EDP_flag==5
        dvalues_act=msa.EDP_d_max_cl;
    elseif  EDP_flag==6
        dvalues_act=msa.EDP_res_max_cl;
    elseif  EDP_flag==7
        dvalues_act=msa.EDP_d_quadmax_cl;
    elseif  EDP_flag==8
        dvalues_act=msa.EDP_res_quad_cl;
    elseif  EDP_flag==9
                dvalues_act=msa.EDP_d_x_cl/Disp_lim(1);      
    elseif  EDP_flag==10
                dvalues_act=msa.EDP_d_y_cl/Disp_lim(1);  
    elseif  EDP_flag==11
                dvalues_act=msa.EDP_res_x_cl/Disp_lim(1);  
    elseif  EDP_flag==12
                dvalues_act=msa.EDP_res_y_cl/Disp_lim(1);  
    elseif  EDP_flag==13
                dvalues_x_D_C=msa.EDP_d_x_cl/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_d_y_cl/Disp_lim(2);
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==14
                dvalues_x_D_C=msa.EDP_res_x_cl/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_res_y_cl/Disp_lim(2);
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==15
                dvalues_x_D_C=msa.EDP_d_x_cl/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_d_y_cl/Disp_lim(2);
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
    elseif  EDP_flag==16
                dvalues_x_D_C=msa.EDP_res_x_cl/Disp_lim(1);  
                dvalues_y_D_C=msa.EDP_res_y_cl/Disp_lim(2);
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
    else
        dvalues_act=msa.EDP_d_x_cl;
    end  
end
if  EDP_flag==1
       dlabel='Maximum displacement x (m)'; 
    elseif  EDP_flag==2
       dlabel='Maximum displacement y (m)'; 
    elseif  EDP_flag==3
        dlabel='Residual displacement x (m)'; 
    elseif  EDP_flag==4
        dlabel='Residual displacement y (m)'; 
    elseif  EDP_flag==5
        dlabel='Maximum displacement (m)'; 
    elseif  EDP_flag==6
        dlabel='Maximum residual displacement (m)'; 
    elseif  EDP_flag==7
        dlabel='Displacement quadratic combination along x and y (m)';
    elseif  EDP_flag==8
        dlabel='Residual displacement quadratic combination along x and y (m)';
    elseif  EDP_flag==9
        dlabel='D/C (Maximum displacement x)[ ]'; 
    elseif  EDP_flag==10
        dlabel='D/C Maximum displacement y [ ]'; 
    elseif  EDP_flag==11
        dlabel='D/C Residual displacement x [ ]'; 
    elseif  EDP_flag==12
        dlabel='D/C Residual displacement y [ ]'; 
    elseif  EDP_flag==13
        dlabel='D/C Maximum displacement [ ]'; 
    elseif  EDP_flag==14
        dlabel='D/C Maximum residual displacement [ ]'; 
    elseif  EDP_flag==15
        dlabel='D/C Displacement quadratic combination along x and y [ ]';
    elseif  EDP_flag==16
        dlabel='D/C Residual displacement quadratic combination along x and y [ ]';
    else
        dlabel='D/C Maximum displacement x (m)'; 
end
end
