function [dvalues_act,dlabel]=fn_check_EDP_IM_MSA_1dir(msa,EDP_flag,Disp_lim,flag_no_sc)   
% check_EDP_IM_MSA_1dir
%-------------------------------------
% DESCRIPTION:
% In the modified IDA structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% ida:            MSA structure from trace_IDA
% EDP_flag:       1 for disp max_x, 2 for disp_max_y, 3 for max_res_x, 4
%                 for max_res_y, 5 for max disp along 2 dir, 6 for max residual disp
%                 along 2 direction, 7 for quadratic combination between displacements,
%                 8 for quadratic combination between residual disp
% Disp_lim:       Limit for D/C. It is a vector for x and y combination
%                 while it is a scalar value for x and y individually
% flag_no_sc:  If it is = 1 a Cloud analysis has been performed, so
%              structure is not a matrix but a vector (EDP,IM)
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% dvalues_act:    results from traceIDA for MSA, active EDP 
% dlabel:         String for x label in EDP-IM plot
%--------------------------------------------------------------------------
if nargin<4
    flag_no_sc=0;
end
if nargin<3
    Disp_lim=[];
    flag_no_sc=0;
end
if EDP_flag>8 & isempty(Disp_lim)
    h=warndlg('Set a capacity limit!','Warning');
    warning('Set a capacity limit!');
    waitfor(h)
    return
end

if flag_no_sc~=1
    if  EDP_flag==1
       dvalues_act=msa.EDP;  
    elseif  EDP_flag==2
         dvalues_act=msa.EDP_res_x;
    elseif  EDP_flag==3
        dvalues_act=msa.EDP/Disp_lim(1); 
    elseif  EDP_flag==4
        dvalues_act=msa.EDP_res_x/Disp_lim(1);
    else
        dvalues_act=msa.EDP;
    end
else
    if  EDP_flag==1
       dvalues_act=msa.EDP_cl;  
    elseif  EDP_flag==2
         dvalues_act=msa.EDP_res_x_cl;
    elseif  EDP_flag==3
        dvalues_act=msa.EDP_cl/Disp_lim(1); 
    elseif  EDP_flag==4
        dvalues_act=msa.EDP_res_x_cl/Disp_lim(1);
    else
        dvalues_act=msa.EDP_cl;
    end
end

if  EDP_flag==1
       dlabel='Maximum displacement x (m)'; 
    elseif  EDP_flag==2
       dlabel='Residual displacement x (m)'; 
    elseif  EDP_flag==3
        dlabel='D/C (Maximum displacement x)[ ]'; 
    elseif  EDP_flag==4
        dlabel='D/C Residual displacement x [ ]'; 
    else
        dlabel='Maximum displacement x (m)';
end
end
