function [dvalues_act,svalues_act]=fn_check_EDP_IM_mu_r_msa(msa,IM_flag,EDP_flag,dy_val,sy_val,flag_no_sc)   
% fn_check_EDP_IM_mu_r_msa
%-------------------------------------
% DESCRIPTION:
% In the modified msa structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% msa:            msa structure from trace_IDA
% IM_flag:        1 for Sa_x(T1), 2 for Sa_y(T1), 3 for max
%                 between Sa_y and Sa_x, 4 for quadratic combination along the 2
%                 direction
% EDP_flag:       1 for disp max_x, 2 for disp_max_y, 3 for max_res_x, 4
%                 for max_res_y, 5 for max disp along 2 dir, 6 for max residual disp
%                 along 2 direction, 7 for quadratic combination between displacements,
%                 8 for quadratic combination between residual disp
% dy_val,sy_val   Yielding point (displacement ad accellaration)
% 
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% dvalues_act,svalues_act:  results from traceIDA, active EDP and IM 
%--------------------------------------------------------------------------
if flag_no_sc~=1
    if IM_flag==1
            svalues_act=msa.IM/sy_val(1); 
    elseif IM_flag==2
            svalues_act=msa.IM/sy_val(2);
    else
            svalues_act=msa.IM/sy_val(1); 
    end

    if   EDP_flag==1 || EDP_flag==9
                dvalues_act=msa.EDP_d_x/dy_val(1);  
     elseif EDP_flag==2 || EDP_flag==10
                dvalues_act=msa.EDP_d_y/dy_val(2);  
    elseif  EDP_flag==3 || EDP_flag==11
                dvalues_act=msa.EDP_res_x/dy_val(1);   
    elseif  EDP_flag==4 || EDP_flag==12
                dvalues_act=msa.EDP_res_y/dy_val(2);  
    elseif  EDP_flag==5 || EDP_flag==13
                dvalues_x_D_C=msa.EDP_d_x/dy_val(1);  
                dvalues_y_D_C=msa.EDP_d_y/dy_val(2);
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==6 || EDP_flag==14
                dvalues_x_D_C=msa.EDP_res_x/dy_val(1);  
                dvalues_y_D_C=msa.EDP_res_y/dy_val(2);
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==7 || EDP_flag==15
                dvalues_x_D_C=msa.EDP_d_x/dy_val(1);  
                dvalues_y_D_C=msa.EDP_d_y/dy_val(2);
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
     elseif  EDP_flag==8 || EDP_flag==16
                dvalues_x_D_C=msa.EDP_res_x/dy_val(1);  
                dvalues_y_D_C=msa.EDP_res_y/dy_val(2);
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
    else
                dvalues_act=msa.EDP_d_x/dy_val(1);
    end
else
    if IM_flag==1
            svalues_act=msa.IM_cl/sy_val(1); 
    elseif IM_flag==2
            svalues_act=msa.IM_cl/sy_val(2);
    else
            svalues_act=msa.IM_cl/sy_val(1); 
    end

    if   EDP_flag==1 || EDP_flag==9
                dvalues_act=msa.EDP_d_x_cl/dy_val(1);  
     elseif EDP_flag==2 || EDP_flag==10
                dvalues_act=msa.EDP_d_y_cl/dy_val(2);  
    elseif  EDP_flag==3 || EDP_flag==11
                dvalues_act=msa.EDP_res_x_cl/dy_val(1);   
    elseif  EDP_flag==4 || EDP_flag==12
                dvalues_act=msa.EDP_res_y_cl/dy_val(2);  
    elseif  EDP_flag==5 || EDP_flag==13
                dvalues_x_D_C=msa.EDP_d_x_cl/dy_val(1);  
                dvalues_y_D_C=msa.EDP_d_y_cl/dy_val(2);
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==6 || EDP_flag==14
                dvalues_x_D_C=msa.EDP_res_x_cl/dy_val(1);  
                dvalues_y_D_C=msa.EDP_res_y_cl/dy_val(2);
                dvalues_act=max(dvalues_x_D_C,dvalues_y_D_C);
    elseif  EDP_flag==7 || EDP_flag==15
                dvalues_x_D_C=msa.EDP_d_x_cl/dy_val(1);  
                dvalues_y_D_C=msa.EDP_d_y_cl/dy_val(2);
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
     elseif  EDP_flag==8 || EDP_flag==16
                dvalues_x_D_C=msa.EDP_res_x_cl/dy_val(1);  
                dvalues_y_D_C=msa.EDP_res_y_cl/dy_val(2);
                dvalues_act=sqrt(dvalues_x_D_C.^2+dvalues_y_D_C.^2);
    else
                dvalues_act=msa.EDP_d_x_cl/dy_val(1);
    end
end