function [dvalues_act,svalues_act]=check_EDP_IM(ida,IM_flag,EDP_flag,Disp_lim)   
% check_EDP_IM
%-------------------------------------
% DESCRIPTION:
% In the modified IDA structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% ida:            IDA structure from trace_IDA
% IM_flag:        1 for Sa_x(T1), 2 for Sa_y(T1), 3 for max
%                 between Sa_y and Sa_x, 4 for quadratic combination along the 2
%                 direction
% EDP_flag:       1 for disp max_x, 2 for disp_max_y, 3 for max_res_x, 4
%                 for max_res_y, 5 for max disp along 2 dir, 6 for max residual disp
%                 along 2 direction, 7 for quadratic combination between displacements,
%                 8 for quadratic combination between residual disp
% Disp_lim:       Limit for D/C. It is a vector for x and y combination
%                 while it is a scalar value for x and y individually
% 
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% dvalues_act,svalues_act:  results from traceIDA, active EDP and IM 
%--------------------------------------------------------------------------
if nargin<4
    Disp_lim=[];
end
if IM_flag==1
   svalues_act=ida.svalues;  
elseif IM_flag==2
    svalues_act=ida.svalues_y;
elseif IM_flag==3
    svalues_act=ida.svalues_max;
elseif IM_flag==4
    svalues_act=ida.svalues_quadmax;
else
    svalues_act=ida.svalues;
end

if  EDP_flag==1
   dvalues_act=ida.dvalues;  
elseif  EDP_flag==2
    dvalues_act=ida.dvalues_y;
elseif  EDP_flag==3
    dvalues_act=ida.max_res_x;
elseif  EDP_flag==4
    dvalues_act=ida.max_res_y;
elseif  EDP_flag==5
    dvalues_act=ida.dvalues_max;
elseif  EDP_flag==6
    dvalues_act=ida.max_res_max;
elseif  EDP_flag==7
    dvalues_act=ida.dvalues_quadmax;
elseif  EDP_flag==8
    dvalues_act=ida.max_res_quad;
elseif  EDP_flag==9
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.dvalues{i}/Disp_lim(1));  
    end
    
elseif  EDP_flag==10
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.dvalues_y{i}/Disp_lim(1));  
    end
elseif  EDP_flag==11
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.max_res_x{i}/Disp_lim(1));  
    end
elseif  EDP_flag==12
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.max_res_y{i}/Disp_lim(1));  
    end
elseif  EDP_flag==13
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.dvalues{i}/Disp_lim(1));  
            dvalues_y_D_C{i}=abs(ida.dvalues_y{i}/Disp_lim(2));
            dvalues_act{i}=max(dvalues_x_D_C{i},dvalues_y_D_C{i});
    end
elseif  EDP_flag==14
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.max_res_x{i}/Disp_lim(1));  
            dvalues_y_D_C{i}=abs(ida.max_res_y{i}/Disp_lim(2));
            dvalues_act{i}=max(dvalues_x_D_C{i},dvalues_y_D_C{i});
    end
elseif  EDP_flag==15
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.dvalues{i}/Disp_lim(1));  
            dvalues_y_D_C{i}=abs(ida.dvalues_y{i}/Disp_lim(2));
            dvalues_act{i}=sqrt(dvalues_x_D_C{i}.^2+dvalues_y_D_C{i}.^2);
    end
    dvalues_act=ida.dvalues_quadmax;
elseif  EDP_flag==16
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.max_res_x{i}/Disp_lim(1));  
            dvalues_y_D_C{i}=abs(ida.max_res_y{i}/Disp_lim(2));
            dvalues_act{i}=sqrt(dvalues_x_D_C{i}.^2+dvalues_y_D_C{i}.^2);
    end
else
    dvalues_act=abs(ida.dvalues);
end
