function [dvalues_act,svalues_act]=check_EDP_IM_mu_r(ida,IM_flag,EDP_flag,dy_val,sy_val)   
% check_EDP_IM_mu_r
%-------------------------------------
% DESCRIPTION:
% In the modified IDA structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% ida:            IDA structure from trace_IDA
% IM_flag:        1 for Sa_x(T1), 2 for Sa_y(T1), 3 for max
%                 between Sa_y and Sa_x, 4 for quadratic combination along the 2
%                 direction
% EDP_flag:       1 for disp max_x, 2 for disp_max_y, 3 for max_res_x, 4
%                 for max_res_y, 5 for max disp along 2 dir, 6 for max residual disp
%                 along 2 direction, 7 for quadratic combination between displacements,
%                 8 for quadratic combination between residual disp
% dy_val,sy_val   Yieldind point (displacement ad accellaration)
% 
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% dvalues_act,svalues_act:  results from traceIDA, active EDP and IM 
%--------------------------------------------------------------------------
if nargin<3
    Disp_lim=[];
end
if IM_flag==1
    for i=1:length(ida.dvalues)
        svalues_act{i}=abs(ida.svalues{i}/sy_val(1)); 
    end
elseif IM_flag==2
    for i=1:length(ida.dvalues)
        svalues_act{i}=abs(ida.svalues_y{i}/sy_val(2));
    end
elseif IM_flag==3
    for i=1:length(ida.dvalues)
            svalues_x_D_C{i}=abs(ida.svalues{i}/sy_val(1));  
            svalues_y_D_C{i}=abs(ida.svalues_y{i}/sy_val(2));
            svalues_act{i}=max(dvalues_x_D_C{i},dvalues_y_D_C{i});
    end
elseif IM_flag==4
        for i=1:length(ida.dvalues)
            svalues_x_D_C{i}=abs(ida.svalues{i}/sy_val(1));  
            svalues_y_D_C{i}=abs(ida.svalues_y{i}/sy_val(2));
            svalues_act{i}=sqrt(svalues_x_D_C{i}*svalues_y_D_C{i});
        end
else
    for i=1:length(ida.dvalues)
        svalues_act{i}=abs(ida.svalues{i}/sy_val(1)); 
    end
end

if   EDP_flag==1 || EDP_flag==9
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.dvalues{i}/dy_val(1));  
    end
    
elseif EDP_flag==2 || EDP_flag==10
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.dvalues_y{i}/dy_val(2));  
    end
elseif  EDP_flag==3 || EDP_flag==11
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.max_res_x{i}/dy_val(1));   
    end
elseif  EDP_flag==4 || EDP_flag==12
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.max_res_y{i}/dy_val(2));  
    end
elseif  EDP_flag==5 || EDP_flag==13
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.dvalues{i}/dy_val(1));  
            dvalues_y_D_C{i}=abs(ida.dvalues_y{i}/dy_val(2));
            dvalues_act{i}=max(dvalues_x_D_C{i},dvalues_y_D_C{i});
    end
elseif  EDP_flag==6 || EDP_flag==14
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.max_res_x{i}/dy_val(1));  
            dvalues_y_D_C{i}=abs(ida.max_res_y{i}/dy_val(2));
            dvalues_act{i}=max(dvalues_x_D_C{i},dvalues_y_D_C{i});
    end
elseif  EDP_flag==7 || EDP_flag==15
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.dvalues{i}/dy_val(1));  
            dvalues_y_D_C{i}=abs(ida.dvalues_y{i}/dy_val(2));
            dvalues_act{i}=sqrt(dvalues_x_D_C{i}.^2+dvalues_y_D_C{i}.^2);
    end
    dvalues_act=ida.dvalues_quadmax;
elseif  EDP_flag==8 || EDP_flag==16
    for i=1:length(ida.dvalues)
            dvalues_x_D_C{i}=abs(ida.max_res_x{i}/dy_val(1));  
            dvalues_y_D_C{i}=abs(ida.max_res_y{i}/dy_val(2));
            dvalues_act{i}=sqrt(dvalues_x_D_C{i}.^2+dvalues_y_D_C{i}.^2);
    end
else
    for i=1:length(ida.dvalues)
            dvalues_act{i}=abs(ida.dvalues{i}/dy_val(1));  
    end
end