function cs = cscvn2(points)
%CSCVN `Natural' or periodic cubic spline curve.
%
%   CS  = CSCVN(POINTS)
%
%   returns a parametric `natural' cubic spline which interpolates to
%   the given points POINTS(:,i)  at parameter values  t(i) ,
%   i=1,2,..., with  t(i)  chosen by Eugene Lee's centripetal scheme,
%   i.e., as accumulated squareroot of chord-length.
%
%   When first and last point coincide, a parametric periodic cubic spline
%   is constructed instead. However, double points result in corners.
%__________________________________________________________________
% Revised by D.Vamvatsikos to include a normalization scheme of 
% the (x,y) coordinates of the fitted points. This has the advantage of
% providing a smoother fit in general (as "t" is now influenced equally
% by both x,y, instead of just one that happens to be on larger scale)
% This is especially beneficial for drifts and Sas where typicaly 
% 0<Sa<4 and 0<drift<0.2, which makes them quite uneven.

% (Last updated: September 3rd, 1999)
% Copyright (c) 1999 by D.Vamvatsikos

%// coordinate rescaling: Make the maximums to be equal.
mp2=max(points(2,:));
mp1=max(points(1,:));

if (mp2~=0)&(mp1~=0)
  scalefactor=mp1/mp2;
else
  %// do not scale!
  scalefactor=1;
end

points(2,:)=points(2,:)*scalefactor;

%// Now continue with fitting through cscvn.m !!
cs=cscvn(points);

%// reverse the coordinate transform by scaling down the
%// coefficients of the relevant polynomial pieces

[breaks,coefs]=ppbrk(cs);
coefs(2:2:size(coefs,1),:)=1/scalefactor*coefs(2:2:size(coefs,1),:);
%// now put back "cv" using the old breaks and the new coefficients.
cs=ppmak(breaks,coefs,2);
