function [svalues_act]=eval_SF_forT(ida,svalues,T_IM,IM_flag,Sa_active)   
% eval_SF
%-------------------------------------
% DESCRIPTION:
% In the modified IDA structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP after the
% interpolation from Sa(T_periods) to Sa(T_IM)
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% ida:            IDA structure from trace_IDA
% svalues:        results from traceIDA, active EDP and IM
% IM_flag:        1 for Sa_x(T1), 2 for Sa_y(T1), 3 for max
%                 between Sa_y and Sa_x, 4 for quadratic combination along the 2
%                 direction
% Sa_active:      Sa at predefined ni.
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% svalues_ac:    IM at T_IM period
%--------------------------------------------------------------------------

if ~isempty(ida) & ~isempty(svalues) & ~isempty(T_IM) & ~isempty(IM_flag) & ~isempty(Sa_active)
    % Valuta Sa_x ed Sa_y allo smorzamento fissato:
    [svalues_x]=eval_SF_forvi(ida,ida.T_int,ida.Sa,Sa_active,ida.T_periods,1); 
    [svalues_y]=eval_SF_forvi(ida,ida.T_int,ida.Sa,Sa_active,ida.T_periods,2); 
    Sa_int=interp1(ida.T_int,Sa_active,T_IM);
    Sa_int1=interp1(ida.T_int,Sa_active,ida.T_periods);
    rapp=Sa_int./Sa_int1;
    if IM_flag==1
            rapp=rapp(1:2:end);
                for i=1:length(svalues)
                   svalues_act{i}=svalues_x{i}*rapp(i);
                end

    elseif IM_flag==2
          rapp=rapp(2:2:end);
                for i=1:length(svalues)                 
                    svalues_act{i}=svalues_y{i}*rapp(i);
                end
    elseif IM_flag==3
          rapp_x=rapp(1:2:end);
          rapp_y=rapp(2:2:end);
                for i=1:length(svalues)                    
                    svalues_x{i}=svalues_x{i}*rapp_x(i);
                    svalues_y{i}=svalues_y{i}*rapp_y(i);
                    svalues_act{i}=max(svalues_x{i},svalues_y{i});
                end
    elseif IM_flag==4
          rapp_x=rapp(1:2:end);
          rapp_y=rapp(2:2:end);
                for i=1:length(svalues)                   
                    svalues_x{i}=svalues_x{i}*rapp_x(i);
                    svalues_y{i}=svalues_y{i}*rapp_y(i);
                    svalues_act{i}=sqrt(svalues_y{i}.*svalues_x{i});
                end
    else
        rapp=rapp(1:2:end);
                for i=1:length(svalues)                  
                    svalues_act{i}=svalues_x{i}*rapp(2*i-1);
                end
    end
end
