function [svalues_act]=eval_SF_forvi(s,T_int,Sa,Sa_mod,T_periods,IM_flag)   

% eval_SF
%-------------------------------------
% DESCRIPTION:
% In the modified IDA structure for a bidimensional SDOF system (see
% simplestSDOF_2dir.tcl) this function set active IM and EDP after the
% interpolation from Sa(ida.T_periods) to Sa(T_IM)
% 
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% s:              Structure from traceIDA modified
% T_int:          Vector fo period in correspondence of spectra are
%                 evaluated
% Sa:             Spectral accelleration at T1 and vi=5%
% Sa_mod:         Spectral accelleration at T1 and vi=damp_IM (see GUI)
% T_periods:      Structural period  
% IM_flag:        1 for Sa_x(T1), 2 for Sa_y(T1), 3 for max
%                 between Sa_y and Sa_x, 4 for quadratic combination along the 2
%                 direction
%--------------------------------------------------------------------------
% OUTPUT:
%--------------------------------------------------------------------------
% svalues_act:    IM at damp_IM%
%--------------------------------------------------------------------------
if ~isempty(T_int) & ~isempty(Sa) & ~isempty(Sa_mod) & ~isempty(T_periods)
    Sa_int_vi=interp1(T_int,Sa_mod,T_periods);
    Sa_int1_vi=interp1(T_int,Sa,T_periods);
    rapp=Sa_int_vi./Sa_int1_vi;
    if IM_flag==1
            rapp=rapp(1:2:end);
                for i=1:length(Sa_int_vi)/2                   
                    svalues_act{i}=s.svalues{i}*rapp(i);
                end

    elseif IM_flag==2
          rapp=rapp(2:2:end);
                for i=1:length(Sa_int_vi)/2                   
                    svalues_act{i}=s.svalues_y{i}*rapp(i);
                end
    elseif IM_flag==3
          rapp_x=rapp(1:2:end);
          rapp_y=rapp(2:2:end);
                for i=1:length(Sa_int_vi)/2                   
                    svalues_x{i}=s.svalues{i}*rapp_x(i);
                    svalues_y{i}=s.svalues_y{i}*rapp_y(i);
                    svalues_act{i}=max(svalues_x{i},svalues_y{i});
                end
    elseif IM_flag==4
          rapp_x=rapp(1:2:end);
          rapp_y=rapp(2:2:end);
                for i=1:length(Sa_int_vi)/2                  
                    svalues_x{i}=s.svalues{i}*rapp_x(i);
                    svalues_y{i}=s.svalues_y{i}*rapp_y(i);
                    svalues_act{i}=sqrt(svalues_y{i}.*svalues_x{i});
                end
    else
        rapp=rapp(1:2:end);
                for i=1:length(Sa_int_vi)/2                   
                    svalues_act{i}=s.svalues{i}*rapp(2*i-1);
                end
    end
else
    svalues_act=[];
end
