function [dl Fl] =get_backbone(fy,deltay,ah,mu_c,ac,rp,mu_f)

% Function get_backbone
%-------------------------------------
% DESCRIPTION:
% the function allows get all types of linearized curve 
% 
%-------------------------------------
% INPUT:
%-------------------------------------

% fy:         yield strength;
% deltay:     yield displacement;
% ah:         ratio between hardening slope and elastic slope;
% mu_c:       mu at the end of hardening slope; 
% ac:         ratio between negative (capping) slope and elastic slope;
% rp:         Residual plateau height, a fraction of Fy;
% mu_f:       fracturing mu (deltay * mu_f is the end of SPO);
%-------------------------------------
% OUTPUT:
%-------------------------------------
% [dl,Fl]:    Linearized curve. dl is displacement vector, Fl is force
% vector
if rp>1
    rp=0;
end


    k=fy/deltay;
     % Elastic - perfectly plastic curve 
     if rp==0 && ac==0 && ah==0
     Fl=[0,fy,fy+ah*k*(mu_f*deltay-deltay)];
     dl=[0,deltay,mu_f*deltay];
     end
    
    % Elastic - plastic (hardening) curve 
    if rp==0 && ac==0  && ah~=0 
    Fl=[0,fy,fy+ah*k*(mu_f*deltay-deltay)];
    dl=[0,deltay,mu_f*deltay];
    end
    
    % Elastic - plastic (softening) curve 
    if rp==0 && ac~=0  && ah==0
    Fl=[0,fy,fy+ac*k*(DELTA(end)-deltay)];
    dl=[0,deltay,DELTA(end)];
   [x1,y1]=polyxpoly(DELTA,F,dl,Fl);
    end
    
    % 22/04/2016. Matlab 2009b gives a warning message if it divedes by 0.
    % For this reason we use the following trick:

    delta_end=mu_c*deltay+((fy+ah*k*mu_c*deltay-ah*k*deltay)/(abs(ac*k)));

   % Tri-linearized curve
   if rp==0 && mu_c~=0 && ac~=0
   Fl=[0,fy,fy+ah*k*(mu_c*deltay-deltay),fy+ah*k*(mu_c*deltay-deltay)+((delta_end-mu_c*deltay)*ac*k)];
   dl=[0,deltay,mu_c*deltay,delta_end];
   end
      
   % Quadri-linearized curve with residual plateau
   % 28/04/2016: Add vertical line at the end of quadrilinear curve
   if rp~=0 && mu_c~=0 && ac~=0
   Fl=[0,fy,fy+ah*k*(mu_c*deltay-deltay),fy+ah*k*(mu_c*deltay-deltay)+((mu_f*deltay-mu_c*deltay)*ac*k),0];
   dl=[0,deltay,mu_c*deltay,mu_f*deltay,mu_f*deltay];
   Frp=rp*fy;
   y=Frp*ones(size(dl));
   [x1,~]=polyxpoly(dl(1:end-1),Fl(1:end-1),dl,y);
   x=x1(end);
%    if x<deltay
%        errordlg('check input data, absurd value of some parameter','error')
%        error('check input data, absurd value')
%    end
   
      if x>deltay
      Fl=[0,fy,fy+ah*k*(mu_c*deltay-deltay),rp*fy,rp*fy,0];
      dl=[0,deltay,mu_c*deltay,x,mu_f*deltay,mu_f*deltay];
      end
   end
   

       
% a={@getPoint,dy,Fel};
% legend(p_el,'SPO Linear Elastic Limit','location','best')
% legend boxoff
% annotation('textbox',...
%     [X Y 0.1 0.1],...
%     'String','SPO Linear Elastic Limit',...
%     'FontSize',8,...
%     'EdgeColor','none',...
%     'units','normalized',...
%     'FontName','Times New Roman');

%    plot(dl,Fl,'--','color',[1 0 0],'LineWidth',1.5);hold on;
%    plot(dl,Fl,'ok','MarkerFaceColor','r'); hold off;



