function [ bin_edges ] = get_bin_edges( bin_centers )
% This function accepts as input a row Mx1 vector OR an MxN matrix defining
% bin centers along its rows, and outputs bin edges in vector or matrix
% form
%=====================================================
%                        INPUT
%=====================================================
% bin_centers         ->   row Mx1 vector OR an MxN matrix defining
%                          bin centers along its rows
%=====================================================
%                        OUTPUT
%=====================================================
% bin_edges     ->  row (M+1)x1 vector OR (M+1)xN matrix 
%                   defining bin edges along its rows
%------------------------------------------------------------
%                      CHANGELOG
%------------------------------------------------------------
% UPDATED 20 October 2015: Added matrix input functionality
%------------------------------------------------------------
d = 0.5*diff(bin_centers,1,2); % 1st level difference operation along rows (dim=2)
bin_edges = [bin_centers(:,1)-d(:,1), bin_centers(:,1:end-1)+d, bin_centers(:,end)+d(:,end)];
end

