function [ eta_hat, beta_hat ] = get_params( IM_stripe, method )
% This function estimates the IM-based  lognormal fragility parameters
% given a comple IDA stripe with the intensities causling failure
%=====================================================
%                        INPUT
%=====================================================
% IM_stripe      ->    column Nx1 vector: IDA stripe containing IM 
%                      values that cause failure
% Method         ->   0 for eta estimated as median, 1 for geomean                   
%=====================================================
%                        OUTPUT
%=====================================================
% eta_hat         ->   mean of the logs of the lognormal fragility
% beta_hat        ->   logarithmic standard deviation of the 
%                      lognormal fragility
%------------------------------------------------------------
%                      CHANGELOG
%------------------------------------------------------------


% set default value for method
if nargin<2
    method=0;
end


% Check for suffucient length of stripe!
if length(unique(IM_stripe))<3
    error ('need at least three distint values')
end

% make sure IM_stripe is a column vector!
% this is important for taking counted fractiles correctly!
if size(IM_stripe,1)<size(IM_stripe,2)
IM_stripe=IM_stripe';
end

if method<1
eta_hat=log(quantile(IM_stripe,0.5)); % log of the counted median
else
eta_hat=mean(log(IM_stripe)); % mean of the logs (geomean)
end
beta_hat=(sum((log(IM_stripe)-eta_hat).^2)/(length(IM_stripe)-1)).^0.5; % use central moment around counted median
end

