function plot_qdr_fractile_IDAs(sa_range,qdr,xlim,qs,Hfig,linestyles,...
                                             labelflag,flatline,linew)
%---------------------------------------------
% plot 16,50,84% fractiles given levels of Sa
%
% qdr  : contains the actual fractile drvalues. Each column corresponds to
%        one value of "qs" and each row to one value of sa_range.
% qs   : Contains the NAMES of the fractiles (e.g. 0.16). 
%        NOTE THAT THE FRACTILES ARE NOT COMPUTED ACCORDING TO qs. So if
%        you provide say qdr containing fractiles 16,50,84 and you provide
%        the qs=0.50, it will only plot the 1st column of qdr (the 16% fractile) 
%        and label it as 50%!!! BE VERY CAREFUL HERE
% labelflag: if 0, no labels are created
%            if 1 (default), then labels are set at the end of the curve,
%            if 2, then the labels go direcly beneath the curve, at its end.
%
%
% Updated, Feb 21, 2005: Upgraded to the same standards as plot_cv_IDAs by
%                        adding the options: linestyles,labelflag,flatline and
%                        linew. I have also fixed the linestyle, pointstyle
%                        assignment scheme. 
%                        Now it is perfect so that the first IDA always 
%                        gets the first linestyle & pointstyle!
%                        Have also forced plotting only the non-NaN or non-Inf
%                        drifts, otherwise the y-axis can have a large max
%                        limit
% Updated, Oct 30, 2005: Changed "linestyles" option, so that it is now a cell of 
%                        three cells! This allows setting a lot of options
%                        for each line, even specialized colors and
%                        markings. I have also remove the "clf", so that
%                        these plots can be combined with others that have
%                        been previously created. It also returns now
%                        handels to the (main) lines created, useful for
%                        legends!
% Updated, 16/May/2007: Now flatlinefin will not be higher than xlim(2)
%                       limit supplied externally
% Updated, 12/May/2008: if Hfig is supplied but empty then it is
%                       automatically set to 1
% Copyright (c) 1999 by D.Vamvatsikos                      

if nargin<9, linew=2; end
if nargin<8, flatline=0; end
if nargin<7, labelflag=1; end
if nargin<6 || isempty(linestyles)
   % default line styles to use for plotting
   linestyles={{'m--'},{'b-'},{'r-.'}};
end
if nargin<5||isempty(Hfig), Hfig=1; end
if nargin<4, qs=[0.16,0.50,0.84]'; end
if nargin<3, xlim=[]; end 

% determine the dvalue up to which the flatline will be drawn.
% make it to be 10% higher than the maximum dvalue present, or 
% equal to xlim, the externally supplied x-axis limit
if flatline
   % make all the Infs into NaN.
   qdr(isinf(qdr))=NaN;
   maxdv=nanmax(nanmax(qdr));
   if ~isempty(xlim)
      %flatlinefin=max(1.1*maxdv,xlim(2)); 
      if length(xlim)>1
        flatlinefin=xlim(2);
      else
        flatlinefin=xlim; 
      end
   else
      flatlinefin=1.1*maxdv;
   end
end

if labelflag==2
   labelopt={'HorizontalAlignment','right','VerticalAlignment','Top'};
else
   labelopt={};
end
% figure(Hfig); 
linew=1.8;
LineH = get(gca, 'children');
V = get(LineH, 'XData');
for i=1:length(V)
    max_i(i)=max(V{i});
end
flatlinefin=max(max_i);
hold on
for i=1:length(qs)
   indy=find(~isinf(qdr(i,:))&~isnan(qdr(i,:)));
  plot(qdr(i,indy),sa_range(indy),linestyles{mod(i-1,length(linestyles))+1}{:},...
          'linewidth',linew,'color','k','linestyle','--');
   mindy=max(indy);
   if flatline
      plot([qdr(i,mindy),flatlinefin],...
            repmat(sa_range(mindy),1,2),...
            linestyles{mod(i-1,length(linestyles))+1}{:},'linew',linew,'color','k','linestyle','--');
      % put the fractile percentage designator at the end of the curve   
      if labelflag
         text(flatlinefin,sa_range(mindy),sprintf('\\bf %2d%%',round(qs(i)*100)),labelopt{:})
      end
   else
      if labelflag
         text(qdr(i,mindy),sa_range(mindy),sprintf('\\bf %2d%%',round(qs(i)*100)),labelopt{:})
      end
   end
end

% if ~isempty(xlim)
%    set(gca,'xlim',xlim)
% end
% set(gca,'box','on')