function [sa_range,qdr,cv,drval,newval,saval,dr_range]=run_IDA_plot_NoSpo2frag(ida,Path_,dy,plot_name,Nvals,infdr,relaxNaNs,fitcode,val,T_IM,damp_IM,flag_for_plot,EDP_choosen)

% run_SPO2IDA_IDA_plot
%-------------------------------------
% DESCRIPTION:
% the function plot results of SPO2IDA routine with results of IDA analysis
% overlapped in terms of spectral accelleration (IM) and roof displacement 
% (EDP)
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% Spo2ida:          structure containing Spo2ida results (IM and EDP) from GUI
% ida:              structure containing IDA results from traceIDA. It 
%                   contains cell arrays 
%                   1xN of vectors of Sas and drifts
% dy:               Yielding displacement;
% Nvals:            if a single number, then it is the number of values to
%                   compute via spline interpolation both for dr given SA and 
%                   for Sa given dr.
%                   if a vector of two, then first number is as above,
%                   second is the maxdrift up to which you want dr_range to
%                   reach. This is very useful when you want to have
%                   stripes of Sa|drift at the same drift values for
%                   many different buildings (or cases). Note that in this
%                   case only the Nvals(1) is used for the sa-stripes
%                   (dividing up to maxsa).
%                   Otherwise it must be a cell array of length 2. 
%                   Nvals{1} is a SORTED vector of Sa-levels to compute drift
%                   stripes. If empty, no stripes are generated
%                   Nvals{2} similarly a SORTED vector of dr-levels.       
% infdr:            A maximum drift above which the structure is assumed 
%                   collapsed and all such higher drifts are replaced by Inf.
%                   The reason I am using this is that excessive drifts, say 10
%                   have no physical meaning and will make the fits terrible!
%                   Default is "1". Note that if you are fitting normalized R vs mu 
%                   data then something like 20 may be more reasonable! 
% relaxNaNs:        if 0 (default) then the first NaN signals collapse.
%                   This is good for robust models, where we are certain that
%                   convergence is easy to achieve.
%                   if 1 (careful!) then if there exists a convergent run
%                   with drift less than Th_drift directly above an early NaN, 
%                   then that NaN is considered bogus (numerical non-convergence but
%                   not dynamic instability) and it is dropped! So instead
%                   of calling it a "resurrection", we decide that we had
%                   no collapse in the first case. 
%                   if 2 (VERY careful!) even two or more consecutive NaNs could be 
%                   indeed considered collapse if at least one convergent
%                   run (with drift<Th_drift) exists above them. This is
%                   for very shaky models only.
% fitcode:           0 = piecewise linear fit
%                    1 = std. natural splines (cscvn2.m)
% plot_name:         String representing the name of the saved figure
%%------------------------------------------------------------------
% Now plot IDAs
% 
% clc
% clear all
% close all
% this will load anlsout, svalues, dvalues, NCSa
%load LA9_2Dframe_sv01-30_sense_base.sida.mat
% load 8_storey.mat
% load 8_storey_GUI.mat

% load 100_RS.mat
% load 100_RS_GUI.mat
if nargin<13
    EDP_choosen=1;
end
if nargin<12 
    EDP_choosen=1;
    flag_for_plot=1;
end
if nargin<9||isempty(fitcode), fitcode=1; end
if nargin<8, relaxNaNs=0; end
if nargin<7||isempty(infdr), infdr=Inf; end
if nargin<6, Nvals=500;  end
if isempty(EDP_choosen)
    EDP_choosen=1;
end
if isfield(ida,'disp_dyn') 
    if  (EDP_choosen==1 | EDP_choosen==3)
%            if isfield(ida,'res_dyn') 
               flag_for_B2B=ida.disp_dyn;
%            else
%                flag_for_B2B=0;
%            end       
    else
        flag_for_B2B=0;
    end
else
    flag_for_B2B=0;
end


ni_active=0.05;
dvalues=ida.dvalues;
svalues=ida.svalues;
% Questo serve per non darmi problemi quando lancio analisi con 1 record
% solo
if isempty(flag_for_plot)
    qs=[];
else
    qs=[0.16,0.50,0.84]';
end

[dvalues]=check_EDP_IM_1dir(ida,EDP_choosen,infdr(1));
% For D/C plot
% if EDP_choosen>2 & val~=2 & isfield(ida,'disp_dyn')
%     %%%% CONTROLLARE
% %     infdr=ida.disp_dyn/infdr(1)+1/ida.disp_dyn;
%       infdr=infdr(end)/infdr(1);
% elseif EDP_choosen>2 & val~=2 & ~isfield(ida,'disp_dyn')
%     infdr=1;
if EDP_choosen>2 & val==2 & ~isfield(ida,'disp_dyn')
    infdr=infdr(2)/infdr(1);
elseif EDP_choosen>2 & val==2 & isfield(ida,'disp_dyn')   
    infdr=infdr(2)/infdr(1);
end

% for i=1:length(dvalues)
%     dvalues{i}=sort(dvalues{i});
% end

if val~=2
    for i=1:length(dvalues);
        % Per B2B IDA le IDA sono shiftate di disp_dyn
        if isfield(ida,'disp_dyn')
            sy(i)=svalues{i}(2);
            d_y(i)=dy;
            svalues{i}=svalues{i}/svalues{i}(2);
            dvalues{i}=dvalues{i}/(d_y(i));
        else
            sy(i)=svalues{i}(2);
            % In questo caso dy coincide con dvalues{i}(2) (IDA SDOF)
            dy(i)=dvalues{i}(2);
%             for i=1:length(dvalues);
                svalues{i}=svalues{i}/svalues{i}(2);
                dvalues{i}=dvalues{i}/(dy(i));
                dvalues{i}=[[0:0.001:1]';dvalues{i}(3:end)];
                svalues{i}=[[0:0.001:1]';svalues{i}(3:end)];
%             end
        end
    end
    % 

else
    % Change damping in Sa evaluation
    if ~isempty(damp_IM)
            if damp_IM~=5
                    Sa_int_vi=interp1(ida.T_int,ida.Sa_mod,ida.T_periods);
                    Sa_int1_vi=interp1(ida.T_int,ida.Sa,ida.T_periods);
                    rapp_ni=Sa_int_vi./Sa_int1_vi;
                    for i=1:length(ida.Sa(1,:))
                        svalues{i}=svalues{i}*rapp_ni(i);  
                    end
                    % Per la successiva interpolazione a periodi diversi da T1 bisogna
                    % attivare lo spettro allo smorzrapamento corretto:
                    Sa_active=ida.Sa_mod;
                    ni_active=ida.ni_mod;
            else
                    if isfield(ida,'Sa')
                        Sa_active=ida.Sa;
                    else
                        Sa_active=svalues;
                    end
                    ni_active=0.05;
            end
    else
        if isfield(ida,'Sa')
            Sa_active=ida.Sa;
        else
            Sa_active=svalues;
        end
        ni_active=0.05;
    end
    % Interpolation at T_int period:
    if ~isempty(T_IM) 
             Sa_int1=interp1(ida.T_int,Sa_active,ida.T_periods);                 
            if length(T_IM)>1
                Sa_int=geomean(interp1(ida.T_int,Sa_active,T_IM));
            else
                Sa_int=interp1(ida.T_int,Sa_active,T_IM);          
            end
            rapp=Sa_int./Sa_int1;
            for i=1:length(ida.Sa(1,:))
                svalues{i}=svalues{i}*rapp(i);
            end
    else
        T_IM=ida.T_periods;
    end
end

% for i=1:length(dvalues)
%     hold on
%     plot(dvalues{i},svalues{i})
% end

% line styles to use for plotting
linestyles={'m-','r-','g-','b-'};
%linestyles={'m--','r--','g--','b--'};

% Select the number of values to calculate from the interpolation.
%Nvals=500;
% drift abive which all drift values are considered infinite (collapse occurs)
% helps with fitting! Try setting it to 100 to see the difference with some badly
% behaved sets!
%infdr=2.26;
% 
% Excellent trick: If you include any superscript (even an empty one)
% for the ylabel, then matlab places them a bit lower than usual
% resulting in nice looking figs!

[dlabel,slabel]=check_EDP_IM_str_plot_1dir(val,EDP_choosen,ni_active,T_IM);   

%% ****************************************************************
%----------------------------------------
% NOW PROCESS THE max IDR 
%-----------------------------------------
% xlim=([0 max(handles.idac(3).m)]);
% xlim=([0 infdr*1.1]);
% xlim=[];
truncate_dvalue=[]; % no truncation needed. It finds flatline on its own!
%relaxNaNs=0; % Allow removal of "single" intermediate NaNs!
infdr=infdr(end);
if val~=2
truncate_dvalue=infdr(end)/dy(1);  
[cv,cvsa,sa_range,drval,qdr,saval,dr_range,qSa,lowest_C,tdv,tsv,...
     tdvalues,tsvalues]=...
     postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,2*infdr/dy(1),fitcode,...
     truncate_dvalue,relaxNaNs,flag_for_B2B/dy(1));  
    newval=infdr/dy(1);
else
truncate_dvalue=infdr(end);      
[cv,cvsa,sa_range,drval,qdr,saval,dr_range,qSa,lowest_C,tdv,tsv,...
     tdvalues,tsvalues]=...
     postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,2*infdr,fitcode,...
     truncate_dvalue,relaxNaNs,flag_for_B2B);    
    newval=infdr;
end
ch=isnan(qdr);
if ~isempty(ch)
    ch_1=sum(ch(1,:));
    ch_2=sum(ch(2,:));
    ch_3=sum(ch(3,:));
    if ch_1==length(qdr(1,:)) | ch_2==length(qdr(1,:)) | ch_3==length(qdr(1,:))
        cd(Path_)
        h=warndlg('The value set as limit is too small!','Warning');
        warning('The value set as limit is too small!');
        waitfor(h)
        return
    end
end

if ~isempty(flag_for_plot)
%  
 % plot fractiles for the three cases. Careful with the coloring!
%  figure(4);clf
 
% xlim=[0,handles.idac(1).th(end)/dy];
% xlim=[];

 plot_cv_IDAs(tsvalues,tdvalues,cv,lowest_C,[],4,...
             {'c-'},'',0,1,.1);
        
hold on
if val~=2
plot_qdr_fractile_IDAs(sa_range,qdr,infdr/dy(1),qs,4,{{'b-'},{'b-'},{'b-'}},0,1,3);
else
plot_qdr_fractile_IDAs(sa_range,qdr,infdr,qs,4,{{'b-'},{'b-'},{'b-'}},0,1,3);
end
hold on
%% Steel lavoro
% dd=[0,1,0.4226/0.1106 0.7098/0.1106];
% FF=[0,1,1.1225e+03/1.1130e+03,0];
% CLS lavoro
% dd=[0,1,8.519 8.796];
% FF=[0,1,323.6284/314.1791,0];
%  plot(dd,ff,'linewidth',2,'color','r')
% if val~=2
%     for i=1:3
%         ind{i}=find(isnan(qdr(i,:)));
%         if isempty(ind{i})
%             ind{i}=length(qdr(i,:));
%         end
%         plot(infdr/dy(1),sa_range(ind{i}(1)-1),'o','MarkerEdgeColor','k',...
%         'MarkerFaceColor','r',...
%         'MarkerSize',6)
%     end
%      xlim([dvalues{1}(1),infdr/dy(1)*1.1])
% else
%     for i=1:3
%         ind{i}=find(isnan(qdr(i,:)));
%         if isempty(ind{i})
%         ind{i}=length(qdr(i,:));
%         end
%         plot(infdr,sa_range(ind{i}(1)-1),'o','MarkerEdgeColor','k',...
%         'MarkerFaceColor','r',...
%         'MarkerSize',6)
%     end
%     xlim([dvalues{1}(1),infdr*1.1])
% end

%clear xlim
if val~=2
%     hold on
%     plot(1,1,'o','MarkerEdgeColor','k',...
%     'MarkerFaceColor','b',...
%     'MarkerSize',6)
    xlim([0,infdr/dy(1)*1.1])
else
%     hold on
%     plot(dvalues{1}(2),svalues{1}(2),'o','MarkerEdgeColor','k',...
%     'MarkerFaceColor','b',...
%     'MarkerSize',6)
    xlim([0,infdr*1.1])
end
 ylim([0,max(sa_range)*1.02])
 grid on
 set(gca,'box','on','fontsize',10)
 ylabel(slabel,'FontWeight','normal','FontSize',10,'FontName','Times New Roman');
 xlabel(dlabel,'FontWeight','normal','FontSize',10,'FontName','Times New Roman'); 
% else
% qdr=[];
% sa_range=[];
end

% saveas(figure(4),'Ida_curves','fig')
