function [sa_range,qdr,cv,drval,newval,saval,dr_range]=run_IDA_plot_NoSpo2frag_2dir_fortest(ida,Path_,dy,plot_name,Nvals,infdr,relaxNaNs,fitcode,val,T_IM,damp_IM,IM_choosen,EDP_choosen,flag_for_plot)

% run_SPO2IDA_IDA_plot
%-------------------------------------
% DESCRIPTION:
% the function plot results of SPO2IDA routine with results of IDA analysis
% overlapped in terms of spectral accelleration (IM) and roof displacement 
% (EDP)
%--------------------------------------------------------------------------
% INPUT:
%--------------------------------------------------------------------------
% Spo2ida:          structure containing Spo2ida results (IM and EDP) from GUI
% ida:              structure containing IDA results from traceIDA. It 
%                   contains cell arrays 
%                   1xN of vectors of Sas and drifts
% dy:               Yielding displacement and accelleration (dx and sx per x dir dy and sy per y, both per both dir);
% Nvals:            if a single number, then it is the number of values to
%                   compute via spline interpolation both for dr given SA and 
%                   for Sa given dr.
%                   if a vector of two, then first number is as above,
%                   second is the maxdrift up to which you want dr_range to
%                   reach. This is very useful when you want to have
%                   stripes of Sa|drift at the same drift values for
%                   many different buildings (or cases). Note that in this
%                   case only the Nvals(1) is used for the sa-stripes
%                   (dividing up to maxsa).
%                   Otherwise it must be a cell array of length 2. 
%                   Nvals{1} is a SORTED vector of Sa-levels to compute drift
%                   stripes. If empty, no stripes are generated
%                   Nvals{2} similarly a SORTED vector of dr-levels.       
% infdr:            A maximum drift above which the structure is assumed 
%                   collapsed and all such higher drifts are replaced by Inf.
%                   The reason I am using this is that excessive drifts, say 10
%                   have no physical meaning and will make the fits terrible!
%                   Default is "1". Note that if you are fitting normalized R vs mu 
%                   data then something like 20 may be more reasonable! 
% relaxNaNs:        if 0 (default) then the first NaN signals collapse.
%                   This is good for robust models, where we are certain that
%                   convergence is easy to achieve.
%                   if 1 (careful!) then if there exists a convergent run
%                   with drift less than Th_drift directly above an early NaN, 
%                   then that NaN is considered bogus (numerical non-convergence but
%                   not dynamic instability) and it is dropped! So instead
%                   of calling it a "resurrection", we decide that we had
%                   no collapse in the first case. 
%                   if 2 (VERY careful!) even two or more consecutive NaNs could be 
%                   indeed considered collapse if at least one convergent
%                   run (with drift<Th_drift) exists above them. This is
%                   for very shaky models only.
% fitcode:           0 = piecewise linear fit
%                    1 = std. natural splines (cscvn2.m)
% plot_name:         String representing the name of the saved figure
% IM_choosen:        1 for Sa_x(T1), 2 for Sa_y(T1), 3 for max
%                    between Sa_y and Sa_x, 4 for quadratic combination along the 2
%                    direction
% EDP_choosen:       1 for disp max_x, 2 for disp_max_y, 3 for max_res_x, 4
%                    for max_res_y, 5 for max disp along 2 dir, 6 for max residual disp
%                    along 2 direction, 7 for quadratic combination between displacements,
%                    8 for quadratic combination between residual disp
%%------------------------------------------------------------------
% Now plot IDAs
% 
% clc
% clear all
% close all
% this will load anlsout, svalues, dvalues, NCSa
%load LA9_2Dframe_sv01-30_sense_base.sida.mat
% load 8_storey.mat
% load 8_storey_GUI.mat

% load 100_RS.mat
% load 100_RS_GUI.mat
if nargin<14 
    flag_for_plot=1;
end
if nargin<9||isempty(fitcode), fitcode=1; end
if nargin<8, relaxNaNs=0; end
if nargin<7||isempty(infdr), infdr=Inf; end
if nargin<6, Nvals=500;  end
% % Fai valore assoluto perch adesso il recorder salva ricordando il segno:
% for i=1:length(ida.dvalues)
%     ida.dvalues{i}=abs(ida.dvalues{i});
%     ida.svalues{i}=abs(ida.svalues{i});
% end

dy_val=dy(1:2);
sy_val=dy(3:4);

if  EDP_choosen==1 ||  EDP_choosen==3 || EDP_choosen==9 ||  EDP_choosen==11
    dy_inf=dy(1);
elseif EDP_choosen==2 ||  EDP_choosen==4 || EDP_choosen==10 ||  EDP_choosen==12
    dy_inf=dy(2);
else
    dy_inf=dy(1);
end
[dvalues,svalues]=check_EDP_IM(ida,IM_choosen,EDP_choosen,infdr);

% if ~isempty(infdr)
%     infdr=infdr(1);
% end
% For D/C plot
if EDP_choosen>8 & val==2
    if EDP_choosen<12
    infdr=infdr(2)/infdr(1);
    else
    infdr=max(infdr(3)/infdr(1),infdr(3)/infdr(1));   
    end
end

% dvalues=ida.dvalues;
% for i=1:length(dvalues)
%     dvalues{i}=sort(abs(dvalues{i}));
% end

% svalues=ida.svalues;
% Questo serve per non darmi problemi quando lancio analisi con 1 record
% solo
if isempty(flag_for_plot)
    qs=[];
else
    qs=[0.16,0.50,0.84]';
end


ni_active=0.05;
if val~=2
%         if IM_choosen==1 & EDP_choosen==1
                for i=1:length(dvalues);
                        % Per B2B IDA le IDA sono shiftate di disp_dyn
                        if isfield(ida,'disp_dyn')
                            sy(i)=svalues{i}(2);
                            d_y(i)=dy;
                            svalues{i}=svalues{i}/svalues{i}(2);
                            dvalues{i}=dvalues{i}/(d_y(i));
                        else
                          [dvalues,svalues]=check_EDP_IM_mu_r(ida,IM_choosen,EDP_choosen,dy_val,sy_val);
%                               for i=1:length(dvalues)
%                                     dvalues{i}=sort(dvalues{i});
%                               end
                        end
                end
%         end
else
    % Change damping in Sa evaluation
    if ~isempty(damp_IM) 
        if damp_IM~=5
            [svalues]=eval_SF_forvi(ida,ida.T_int,ida.Sa,ida.Sa_mod,ida.T_periods,IM_choosen);   
            % Per la successiva interpolazione a periodi diversi da T1 bisogna
            % attivare lo spettro allo smorzamento corretto:
            Sa_active=ida.Sa_mod;
            ni_active=ida.ni_mod;
        else
            if isfield(ida,'Sa')
                Sa_active=ida.Sa;
            else
                Sa_active=svalues;
            end
            ni_active=0.05;
        end
    else
        if isfield(ida,'Sa')
            Sa_active=ida.Sa;
        else
            Sa_active=svalues;
        end
        ni_active=0.05;
    end
    % Interpolation at T_int period:
    if ~isempty(T_IM)
        [svalues]=eval_SF_forT(ida,svalues,T_IM,IM_choosen,Sa_active);
    else
        T_IM=ida.T_periods;
    end
end

% line styles to use for plotting
linestyles={'m-','r-','g-','b-'};
%linestyles={'m--','r--','g--','b--'};
[dlabel,slabel]=check_EDP_IM_str_plot(val,IM_choosen,EDP_choosen,ni_active,T_IM);   
%% ****************************************************************
%----------------------------------------
% NOW PROCESS THE max IDR 
%-----------------------------------------
% xlim=([0 max(handles.idac(3).m)]);
% xlim=([0 infdr*1.1]);
% xlim=[];
truncate_dvalue=[]; % no truncation needed. It finds flatline on its own!
%relaxNaNs=0; % Allow removal of "single" intermediate NaNs!
infdr=infdr(end);
save('svalues_a','svalues')
save('dvalues_a','dvalues')
dvalues=dvalues([21,18,3,25,8]);
svalues=svalues([21,18,3,25,8]);
dy_=dvalues{1}(2);
for i=1:length(dvalues)
    dvalues{i}=dvalues{i}/dy_;
end
if val~=2
    [cv,cvsa,sa_range,drval,qdr,saval,dr_range,qSa,lowest_C,tdv,tsv,...
    tdvalues,tsvalues]=...
    postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,infdr/dy_inf(1),fitcode,...
    truncate_dvalue,relaxNaNs);  
    newval=infdr/dy_inf(1);
else
    [cv,cvsa,sa_range,drval,qdr,saval,dr_range,qSa,lowest_C,tdv,tsv,...
    tdvalues,tsvalues]=...
    postIDA_simpleprocessIDA(svalues,dvalues,Nvals,qs,infdr,fitcode,...
    truncate_dvalue,relaxNaNs);    
    newval=infdr;
end
save('saval_a','saval')
save('dr_range_a','dr_range')
% for i=1:length(tdvalues)
%     if length(find(isnan(tdvalues{i}(2:end))))==length(tdvalues{i}(2:end))
%         cd(Path_)
%         h=warndlg('The value set as limit is too small!','Warning');
%         warning('The value set as limit is too small!');
%         waitfor(h)
%         return
%     end
% end
ch=isnan(qdr);
if ~isempty(ch)
    ch_1=sum(ch(1,:));
    ch_2=sum(ch(2,:));
    ch_3=sum(ch(3,:));
%     if ch_1==length(qdr(1,:)) | ch_2==length(qdr(1,:)) | ch_3==length(qdr(1,:))
%         cd(Path_)
%         h=warndlg('The value set as limit is too small!','Warning');
%         warning('The value set as limit is too small!');
%         waitfor(h)
%         return
%     end
end
if ~isempty(flag_for_plot)
    plot_cv_IDAs(tsvalues,tdvalues,cv,lowest_C,[],4,...
                 {'c-'},'',0,1,.1);
     hold on
%     if val~=2 
%         plot_qdr_fractile_IDAs(sa_range,qdr,infdr/dy_inf(1),qs,4,{{'b-'},{'b-'},{'b-'}},0,1,3);
%     else
%         plot_qdr_fractile_IDAs(sa_range,qdr,infdr,qs,4,{{'b-'},{'b-'},{'b-'}},0,1,3);
%     end
 %   hold on
%     if val~=2
%         for i=1:3
%             ind{i}=find(isnan(qdr(i,:)));
%             if isempty(ind{i})
%                 ind{i}=length(qdr(i,:));
%             end
%             plot(infdr/dy_inf(1),sa_range(ind{i}(1)-1),'o','MarkerEdgeColor','k',...
%             'MarkerFaceColor','r',...
%             'MarkerSize',6)
%         end
%          xlim([dvalues{1}(1),infdr/dy_inf(1)*1.1])
%     else
%         for i=1:3
%             ind{i}=find(isnan(qdr(i,:)));
%             if isempty(ind{i})
%             ind{i}=length(qdr(i,:));
%             end
%             plot(infdr,sa_range(ind{i}(1)-1),'o','MarkerEdgeColor','k',...
%             'MarkerFaceColor','r',...
%             'MarkerSize',6)
%         end
%         xlim([dvalues{1}(1),infdr*1.1])
%     end
    ylim([0,max(sa_range)*1.02])
    grid on
    set(gca,'box','on','fontsize',10)
    ylabel(slabel,'FontWeight','normal','FontSize',10,'FontName','Times New Roman');
    xlabel(dlabel,'FontWeight','normal','FontSize',10,'FontName','Times New Roman'); 
end

% figure;
% for i=1:length(dvalues)
%     hold on
%     plot(dvalues{i},svalues{i},'o','MarkerEdgeColor','r',...
%     'MarkerFaceColor','k')
% end
% saveas(figure(4),'Ida_curves','fig')
