%------------------------------------------------------------
% Elastic response specra (D,PSV,PSA), Newmark integration. 
%------------------------------------------------------------

% INPUT:
% dt:     Time Interval (Sampling Time) of Record
% Acc:    Ground Motion Acceleration in g 
% zeta:   Damping Ratio in percent (%); e.g. 5
% g:      acceleration of gravity, default 9.81 m/s^2
% maxT:   Max period considered

% OUTPUT:
% T:      Period of natural vibration (sec)
% Spa:    Spectral Pseudo-aceleration
% Spv:    Spectral Pseudo-velocity
% Sd:     Spectral Displacement

function [T,Spa,Spv,Sd]=spectra(dt,Acc,zeta,g,maxT)

u=zeros(length(Acc),1);
v=zeros(length(Acc),1);
ac=zeros(length(Acc),1);
Acc(end+1)=0;
T(1,1)=0.00;
for j=1:round(maxT/dt)                          
    omega(j,1)=2*pi/T(j);      
    m=1;       
    k=(omega(j))^2*m;
    c=2*m*omega(j)*zeta/100;
    K=k+3*c/dt+6*m/(dt)^2;
    a=6*m/dt+3*c;
    b=3*m+dt*c/2;    
  for i=1:length(u)-1
     u(1,1)=0;                      
     v(1,1)=0;
     ac(1,1)=0;    
     df=-(Acc(i+1)-Acc(i))+a*v(i,1)+b*ac(i,1);  
     du=df/K;
     dv=3*du/dt-3*v(i,1)-dt*ac(i,1)/2;
     dac=6*(du-dt*v(i,1))/(dt)^2-3*ac(i,1);
     u(i+1,1)=u(i,1)+du;
     v(i+1,1)=v(i,1)+dv;
     ac(i+1,1)=ac(i,1)+dac;     
  end
    Sd(j,1)=max(abs((u(:,1))));

    Spv(j,1)=Sd(j)*omega(j);
    Spa(j,1)=Sd(j)*(omega(j))^2/g;
    T(j+1,1)=T(j)+dt;
end
Acc(end)=[];
T(end)=[];
Sd(2,1)=0; Spv(1:2,1)=0;Spa(1:2,1)=max(abs(Acc))/g;


