# simpleSDOF.tcl
#
# Simple SDOF file, suitable for static or dynamic analyses.
#-----------------------------------------------------------
# Created 25/Nov/2011, Copyright (c) D. Vamvatsikos
#       Based on my more complex simpleSDOF4.tcl
# Updated 12/Apr/2013, added Elastic and Elastoplastic materials, plus 
#       an absolute acceleration recorder. I have also set runIDAflag=0 in all cases to avoid
#       potential misinterpretations with older output for new users.
#-----------------------------------------------------------
# NOTE: Massproportional damping always works. Stiffness proportional doesn't work if you have
#       only Zerolength elements.
# NOTE: OpenSEES can't do pushovers with SDOFs having negative slope. Even Arclength doesn't converge.
#       The trick I have implemented is to add a parallel elastic spring, thus making sure that my
#       total system always has postive stiffness and both springs have the same imposed displacements.
#       Then I just record only the force of the forces from the degrading spring (that I am interested
#       in after all!).
wipe

# apparently using "\" creates problems, while "/" is fine. This should also work
# just file for UNIX systems so it is much better!!
 puts [pwd]
source [concat [pwd]/util/units_constants_metric.tcl]
source [concat [pwd]/util/CreatePinch4_param.tcl]
source [concat [pwd]/dati.tcl]
source [concat [pwd]/dati_Isteresi.tcl]
source [concat [pwd]/dati_Isteresi_y.tcl]
source [concat [pwd]/analysistype.tcl]


#-----------------------------
# Select type of analysis
#set analysistype "RCycD"
#set analysistype "eigenvalue"
#set analysistype "dynamic"
#set analysistype "pushover"
#set analysistype "D2SPO"
#set analysistype "D2IDA"
#----------------------------------
# select type of structural damping. 
# CAREFUL: Stiffnessproportional == NO damping for this zerolength element, unless explicitly 
# included with a damper or a "tangent damping" for elastic_with_damping material!
set dampingtype "massproportional"
#set dampingtype "stiffnessproportional"
#-------------------------------------
## Default selection of loading protocol for RCycD analysis. Good for ATC stuff!
#set peakpts [list .005 .005 .01 .01 .02 .02 .03 .03 .04 .04 .05 .05 .06 .06 .07 .07 .08 .08 .09 .09 .1 .1 .2 .2 .3 .3 .4 .4 .5 .5 .6 .6 .7 .7 .8 .8 .9 .9 1.0 1.0]
#--------------------------------------
# Displacement step for the pushover
# good for ATC-stuff
#set DispStep  [expr 1e-4]|
# Good for non-ATC stuff
set DispStep  [expr 1e-3*$m]
#------------------------------------
# set material type
#set material "atc62_spring1a"
#set material "atc62_spring1b"
#set material "atc62_spring2a"
#set material "atc62_spring2b"


# if {[file exists "MatIDA_paramfile.tcl"] & $analysistype=="dynamic"} {
   # puts "Using EXTERNAL Parameters data-file (Matlab-generated)"
   source Mat_paramfile.tcl
# } else {
   # puts "Using STANDARD Parameters data-file"
   # source MatCYC_paramfile.tcl
# }


model basic -ndm 2 -ndf 3


#---------------------------------------------------------------------------
# Source the analysistype information. Better to have it in a distinct file 
# especially if running multiple analyses of the same case
# if {[file exists "MatIDA_anlsfile.tcl"]} {
   # puts "Reading EXTERNAL Analysistype file (Matlab-generated)"
   # source MatIDA_anlsfile.tcl
# }


#-------------------------------------------------------------------------------
puts "Analysis: $analysistype"

#-------------------------------------------------------------------------
# Source the timehistory information to apply to the bridge. The default
# file applies "HDA255.AT2.txt" and "HDA165.AT2.txt", upscaled by 7.5
# if {$analysistype=="dynamic" & [file exists "MatIDA_thfile.tcl"]} {
   # set runIDAflag 0
   # puts "Using EXTERNAL Timehistory data-file (Matlab-generated)"
   # source MatIDA_thfile.tcl
# } else {
   # set runIDAflag 0
   # puts "Using STANDARD Timehistory data-file"
   # puts $analysistype
   # puts [pwd]
   # # source MatIDA_thfile.tcl
# }


if {$analysistype=="dynamic" & [file exists [concat [pwd]/MatIDA_thfile.tcl]]} {
   set runIDAflag 1
   puts "Using EXTERNAL Timehistory data-file (Matlab-generated)"
   source MatIDA_thfile.tcl
} elseif {$analysistype=="D2SPO"} {
   set runIDAflag 1
   puts "Using EXTERNAL Timehistory data-file (Matlab-generated)"
   source MatIDA_thfile.tcl
} elseif {$analysistype=="dynamic"} {
   set runIDAflag 0
   puts "Using STANDARD Timehistory data-file"
   source standard_thfile.tcl
   } elseif {$analysistype=="D2IDA"} {
   set runIDAflag 1
   puts "Using EXTERNAL Timehistory data-file (Matlab-generated)"
   source MatIDA_thfile.tcl
} else {
   set runIDAflag 0
}



#-------------------------------------------------------------------------
# max allowed subdivisions of dt. Use 1 for fast runs, but I highly suggest using 2 for better
# accuracy. It allows the structure to go to higher flatlines (at least in a few cases I have tried).
set dtsub 1.0
# number of iterations
set niter 10

#-------------------------------------------------------------------------------
# Define the material to test.
#
puts materiale=$material
set i 1
set ai 1.0
set j 3
 ########################################################################################################
 ########################################################################################################
 # Definisci parametri. I parametri così definiti possono essere usati direttamente per il pinching4 mentre vanno modificati per IMKmodified.

  CreatePinch4_param ePf1 eNf1 ePd1 eNd1 ePf2 eNf2 ePd2 eNd2 ePf3 eNf3 ePd3 eNd3 ePf4 eNf4 ePd4 eNd4 K0 $My $My_neg $fi_y $ah $ac $mu_c $mu_f $mu_c_neg $mu_f_neg $rp
  # Backbone direzione y:
  CreatePinch4_param ePf1_y eNf1_y ePd1_y eNd1_y ePf2_y eNf2_y ePd2_y eNd2_y ePf3_y eNf3_y ePd3_y eNd3_y ePf4_y eNf4_y ePd4_y eNd4_y K0_y $My_y $My_neg_y $fi_y_y $ah_y $ac_y $mu_c_y $mu_f_y $mu_c_neg_y $mu_f_neg_y $rp_y
 
set ePd3_forIMK [expr (-$ePf2+($ac*$K0)*$ePd2)/($ac*$K0)]
set eNd3_forIMK [expr (-$eNf2+($ac*$K0)*$eNd2)/($ac*$K0)]
#puts ePd3_forIMK=$ePd3_forIMK
#puts eNd3_forIMK=$eNd3_forIMK

set ePd3_forIMK_y [expr (-$ePf2_y+($ac_y*$K0_y)*$ePd2_y)/($ac_y*$K0_y)]
set eNd3_forIMK_y [expr (-$eNf2_y+($ac_y*$K0_y)*$eNd2_y)/($ac_y*$K0_y)]
#puts ePd3_forIMK_y=$ePd3_forIMK_y
#puts eNd3_forIMK_y=$eNd3_forIMK_y
 ########################################################################################################
 ########################################################################################################

########################################################################################################
# Direction X
########################################################################################################
 set degflag 0
switch [string tolower $material] {
		pinch4_mod_mat {
     puts "pinching4 --> pinch4_MAT (Gravity frame B)"
     if {$degflag==0} {
 

uniaxialMaterial Pinching4 [expr $i*10] $ePf1 $ePd1 $ePf2 $ePd2 $ePf3 $ePd3 $ePf4 $ePd4 $eNf1 $eNd1 $eNf2 $eNd2 $eNf3 $eNd3 $eNf4 $eNd4 $rDispP $fForceP $uForceP $rDispN $fForceN $uForceN $gK1 $gK2 $gK3 $gK4 $gKLim $gD1 $gD2 $gD3 $gD4 $gDLim $gF1 $gF2 $gF3 $gF4 $gFLim $gE $dmgType;
     } else {
       uniaxialMaterial Pinching4 [expr $i*10] \
                        [expr  $ai*0.25]  0.005  [expr  $ai*1.0]  0.025  [expr  $ai*0.55]  0.04  [expr  $ai*0.55]  0.12\
                        [expr -$ai*0.25] -0.005  [expr -$ai*1.0] -0.025  [expr -$ai*0.55] -0.04  [expr -$ai*0.55] -0.12\
                                 0.5 0.25 0.05 \
				 0.5 0.25 0.05 \
                                 0. 0.1 0. 0. 0.2\
				 0. 0.1 0. 0. 0.2\
                                 0. 0.4 0. 0.4 0.9\
				 10. "energy"

     }
     #uniaxialMaterial MinMax $i [expr $i*10] -min -0.12 -max 0.12

uniaxialMaterial MinMax $i [expr $i*10] -min $eNd4 -max $ePd4

set ki [expr $ePf1/$ePd1]
 } imk_mod_mat {

 # 05/06/17: Setta i parametri per utilizzare IMK modified anzichè il pinching 4
set ki [expr $ePf1/$ePd1]
set as_Plus [expr $ah]	
set as_Neg [expr $ah]	
set My_Plus [expr $ePf1]
set My_Neg [expr $eNf1]

set theta_p_Plus [expr $ePd2-$ePd1]	
set theta_p_Neg [expr -($eNd2-$eNd1)]	
set theta_pc_Plus [expr $ePd3_forIMK-$ePd2]
set theta_pc_Neg [expr -($eNd3_forIMK-$eNd2)]
set Res_Pos [expr $rp]	
set Res_Neg [expr $rp]	
set theta_u_Plus [expr $ePd4]
set theta_u_Neg [expr -$eNd4]
uniaxialMaterial ModIMKPeakOriented [expr $i*10] $K0 $as_Plus $as_Neg $My_Plus $My_Neg $Lamda_S $Lamda_C $Lamda_A $Lamda_K $c_S $c_C $c_A $c_K $theta_p_Plus $theta_p_Neg $theta_pc_Plus $theta_pc_Neg $Res_Pos $Res_Neg $theta_u_Plus $theta_u_Neg $D_Plus $D_Neg
uniaxialMaterial MinMax $i [expr $i*10] -min -$theta_u_Neg -max $theta_u_Plus
 } clough_mat {
set ki [expr $ePf1/$ePd1]
uniaxialMaterial Clough [expr $i*10] $K0 $ePf1 $eNf1 $ah $rp $ac $ePd2 $eNd2 $Lamda_S $Lamda_C $Lamda_A $Lamda_K $c_S $c_C $c_A $c_K
uniaxialMaterial MinMax $i [expr $i*10] -min $eNd4 -max $ePd4
 } eh_mat {
set Hkin $H_kin_per
set Hiso $H_iso_per
set ki [expr $ePf1/$ePd1]
uniaxialMaterial Hardening $i $K0 $ePf1 $Hiso $Hkin
# uniaxialMaterial MinMax $i [expr $i*10] -min $eNd4 -max $ePd4
} steel1_mat {
set ki [expr $ePf1/$ePd1]
uniaxialMaterial Steel01 $i $ePf1 $K0 $ah $a1_st $a2_st $a3_st $a4_st
 } imk_mod_bilin_mat {
set ki [expr $ePf1/$ePd1]
set as_Plus [expr $ah]	
set as_Neg [expr $ah]	
set My_Plus [expr $ePf1]
set My_Neg [expr $eNf1]
set theta_p_Plus [expr $ePd2-$ePd1]	
set theta_p_Neg [expr -($eNd2-$eNd1)]	
set theta_pc_Plus [expr $ePd3_forIMK-$ePd2]
set theta_pc_Neg [expr -($eNd3_forIMK-$eNd2)]
set Res_Pos [expr $rp]	
set Res_Neg [expr $rp]	
set theta_u_Plus [expr $ePd4]
set theta_u_Neg [expr -$eNd4]

uniaxialMaterial Bilin [expr $i*10] $K0 $as_Plus $as_Neg $My_Plus $My_Neg $Lamda_S_bilin $Lamda_C_bilin $Lamda_A_bilin $Lamda_K_bilin $c_S_bilin $c_C_bilin $c_A_bilin $c_K_bilin $theta_p_Plus $theta_p_Neg $theta_pc_Plus $theta_pc_Neg $Res_Pos $Res_Neg $theta_u_Plus $theta_u_Neg $D_Plus_bilin $D_Neg_bilin $n_bilin
uniaxialMaterial MinMax $i [expr $i*10] -min -$theta_u_Neg -max $theta_u_Plus
 } default {
   error "The material requested is non-existent. Check MatIDA_paramfile.tcl"
   exit
}
}
########################################################################################################
# Direction Y
########################################################################################################
switch [string tolower $material_y] {
		pinch4_mod_mat {
     puts "pinching4 --> pinch4_MAT (Gravity frame B)"
     if {$degflag==0} {
 

uniaxialMaterial Pinching4 [expr $j*10] $ePf1_y $ePd1_y $ePf2_y $ePd2_y $ePf3_y $ePd3_y $ePf4_y $ePd4_y $eNf1_y $eNd1_y $eNf2_y $eNd2_y $eNf3_y $eNd3_y $eNf4_y $eNd4_y $rDispP_y $fForceP_y $uForceP_y $rDispN_y $fForceN_y $uForceN_y $gK1_y $gK2_y $gK3_y $gK4_y $gKLim_y $gD1_y $gD2_y $gD3_y $gD4_y $gDLim_y $gF1_y $gF2_y $gF3_y $gF4_y $gFLim_y $gE_y $dmgType_y;
     } else {
       uniaxialMaterial Pinching4 [expr $i*10] \
                        [expr  $ai*0.25]  0.005  [expr  $ai*1.0]  0.025  [expr  $ai*0.55]  0.04  [expr  $ai*0.55]  0.12\
                        [expr -$ai*0.25] -0.005  [expr -$ai*1.0] -0.025  [expr -$ai*0.55] -0.04  [expr -$ai*0.55] -0.12\
                                 0.5 0.25 0.05 \
				 0.5 0.25 0.05 \
                                 0. 0.1 0. 0. 0.2\
				 0. 0.1 0. 0. 0.2\
                                 0. 0.4 0. 0.4 0.9\
				 10. "energy"

     }
uniaxialMaterial MinMax $j [expr $j*10] -min $eNd4_y -max $ePd4_y
set kj [expr $ePf1_y/$ePd1_y]
 } imk_mod_mat {
set kj [expr $ePf1_y/$ePd1_y]
set as_Plus_y [expr $ah_y]	
set as_Neg_y [expr $ah_y]	
set My_Plus_y [expr $ePf1_y]
set My_Neg_y [expr $eNf1_y]

set theta_p_Plus_y [expr $ePd2_y-$ePd1_y]	
set theta_p_Neg_y [expr -($eNd2_y-$eNd1_y)]	
set theta_pc_Plus_y [expr $ePd3_forIMK_y-$ePd2_y]
set theta_pc_Neg_y [expr -($eNd3_forIMK_y-$eNd2_y)]
set Res_Pos_y [expr $rp_y]	
set Res_Neg_y [expr $rp_y]	
set theta_u_Plus_y [expr $ePd4_y]
set theta_u_Neg_y [expr -$eNd4_y]
uniaxialMaterial ModIMKPeakOriented [expr $j*10] $K0_y $as_Plus_y $as_Neg_y $My_Plus_y $My_Neg_y $Lamda_S_y $Lamda_C_y $Lamda_A_y $Lamda_K_y $c_S_y $c_C_y $c_A_y $c_K_y $theta_p_Plus_y $theta_p_Neg_y $theta_pc_Plus_y $theta_pc_Neg_y $Res_Pos_y $Res_Neg_y $theta_u_Plus_y $theta_u_Neg_y $D_Plus_y $D_Neg_y
uniaxialMaterial MinMax $j [expr $j*10] -min -$theta_u_Neg_y -max $theta_u_Plus_y
 } clough_mat {
 set kj [expr $ePf1_y/$ePd1_y]
uniaxialMaterial Clough [expr $j*10] $K0_y $ePf1_y $eNf1_y $ah_y $rp_y $ac_y $ePd2_y $eNd2_y $Lamda_S_y $Lamda_C_y $Lamda_A_y $Lamda_K_y $c_S_y $c_C_y $c_A_y $c_K_y
uniaxialMaterial MinMax $j [expr $j*10] -min $eNd4_y -max $ePd4_y
 } eh_mat {
 set kj [expr $ePf1_y/$ePd1_y]
set Hkin_y $H_kin_per_y
set Hiso_y $H_iso_per_y
uniaxialMaterial Hardening $j $K0_y $ePf1_y $Hiso_y $Hkin_y
# uniaxialMaterial MinMax $i [expr $i*10] -min $eNd4 -max $ePd4
} steel1_mat {
 set kj [expr $ePf1_y/$ePd1_y]
uniaxialMaterial Steel01 $j $ePf1_y $K0_y $ah_y $a1_st_y $a2_st_y $a3_st_y $a4_st_y
 } imk_mod_bilin_mat {
set kj [expr $ePf1_y/$ePd1_y]
set as_Plus_y [expr $ah_y]	
set as_Neg_y [expr $ah_y]	
set My_Plus_y [expr $ePf1_y]
set My_Neg_y [expr $eNf1_y]
set theta_p_Plus_y [expr $ePd2_y-$ePd1_y]	
set theta_p_Neg_y [expr -($eNd2_y-$eNd1_y)]	
set theta_pc_Plus_y [expr $ePd3_forIMK_y-$ePd2_y]
set theta_pc_Neg_y [expr -($eNd3_forIMK_y-$eNd2_y)]
set Res_Pos_y [expr $rp_y]	
set Res_Neg_y [expr $rp_y]	
set theta_u_Plus_y [expr $ePd4_y]
set theta_u_Neg_y [expr -$eNd4_y]
uniaxialMaterial Bilin [expr $j*10] $K0_y $as_Plus_y $as_Neg_y $My_Plus_y $My_Neg_y $Lamda_S_bilin_y $Lamda_C_bilin_y $Lamda_A_bilin_y $Lamda_K_bilin_y $c_S_bilin_y $c_C_bilin_y $c_A_bilin_y $c_K_bilin_y $theta_p_Plus_y $theta_p_Neg_y $theta_pc_Plus_y $theta_pc_Neg_y $Res_Pos_y $Res_Neg_y $theta_u_Plus_y $theta_u_Neg_y $D_Plus_bilin_y $D_Neg_bilin_y $n_bilin_y
uniaxialMaterial MinMax $j [expr $j*10] -min -$theta_u_Neg_y -max $theta_u_Plus_y
 } default {
   error "The material requested is non-existent. Check MatIDA_paramfile.tcl"
   exit
}
}

########################################################################################################
########################################################################################################

#-----------------------------------------  
#   if Tperiod <>0 set the mass to achieve the given period.
#   else set the period to match the given mass!
#-----------------------------------------
set kx $ki
set ky $kj
if {$Tperiod!=0} {
   # set the mass now. It comes in "tons=1000kg"
   # Remember that T=2*pi*sqrt(m/k) <==> m = (T/(2pi))^2*k
   set mx [expr pow($Tperiod/(2*$pi),2)*$kx]
} else {
   set Tperiod 	[expr 2*$pi*sqrt($mx/$kx)]
}

if {$Tperiod_y!=0} {
   # set the mass now. It comes in "tons=1000kg"
   # Remember that T=2*pi*sqrt(m/k) <==> m = (T/(2pi))^2*k
   set my [expr pow($Tperiod_y/(2*$pi),2)*$ky]
} else {
   set Tperiod 	[expr 2*$pi*sqrt($my/$ky)]
}

set omega [expr pow($kx/$mx,0.5)]
set omega_y [expr pow($ky/$my,0.5)]
puts "initial stiffness dir x K=$kx"
puts "Mass dir x              M=$mx"
puts "SDOF period dir x       T=$Tperiod sec"
puts "initial stiffness dir y K=$ky"
puts "Mass dir y             M=$my"
puts "SDOF period dir y      T=$Tperiod_y sec"


# only one material!
set imat_final_x $i
set imat_final_y $j

puts "cyclic frequency x W=$omega rad/sec"
puts "cyclic frequency y  W=$omega_y rad/sec"
# puts "frequency         f=[expr 1.0/$Tperiod] Hz"


node 1 0 0 
node 2 0 0 -mass $mx 0. 0.
node 3 0 0
node 4 0 0 -mass 0. $my 0.
element zeroLength 1 1 2 -mat $imat_final_x   -dir 1
element zeroLength 2 3 4 -mat  $imat_final_y  -dir 2
# equalDOF 1 2 3
# equalDOF 3 4 3
fix 1 1 1 1
fix 2 0 1 1
fix 3 1 1 1
fix 4 1 0 1


 if {$analysistype=="pushover"||$analysistype=="RCycD"} {
 puts "ADDING PARALLEL SPRING FOR PUSHOVER"
 puts "IF NON-CONVERGENCE OCCURS, INCREASE ITS STIFFNESS!"
 uniaxialMaterial Elastic 102 [expr 50*$kx] 0
 node 5 0 0
 node 6 0 0
 node 7 0 0
 node 8 0 0
 element zeroLength 3 5 6 -mat 102 -dir 1 
 element zeroLength 4 7 8 -mat 102 -dir 2 
 # slave node 6 to node 2 and 8 to 4
equalDOF 2 6 1 2 3
equalDOF 4 8 1 2 3
 # fix 6 1 1 1
 # fix 8 1 1 1
 fix 5 1 1 1
 fix 7 1 1 1
 }


recorder Node -file [concat [pwd]/Disp.out] -time -node 2 4 -dof 1 2 disp
recorder Node -file [concat [pwd]/Force.out] -time -node 1 3 -dof 1 2 reaction



 if {!$runIDAflag} {
 recorder Element -file SpringF.out -time -ele 1 force material $imat_final_x
 recorder Node -file NodeV.out -time -node 2 -dof 1 vel
 recorder Node -file NodeA.out -time -node 2 -dof 1 accel
 }




# if {$dampingtype=="massproportional"} {
  # # values taken from chopra, pg. 418.
  # puts "Mass proportional damping [expr $ksi*100]%"
  # set alphaM [expr $ksi*2.0*$omega]
  # set betaKinit 0
# } else {
  # puts "Initial stiffness proportional damping [expr $ksi*100]%"
  # set alphaM 0
  # set betaKinit [expr $ksi*2.0/$omega]
# }

if {$dampingtype=="massproportional"} {
   # values taken from chopra, pg. 418.
  puts "Mass proportional damping x [expr $ksi*100]%"
  set alphaMx [expr $ksi*2.0*$omega]
  set betaKinitx 0
    puts "Mass proportional damping y [expr $ksi_y*100]%"
  set alphaMy [expr $ksi_y*2.0*$omega_y]
  set betaKinity 0
 } 
 
# else {
# # Applica smorzamento mass and stiffness proportional
# if {$omega==$omega_y} {
# set ksi_m [expr ($ksi_y+$ksi)/2.0]
# set alphaMx [expr $ksi_m*2.0*$omega]
# set alphaMy [expr $ksi_m*2.0*$omega]
# set betaKinitx 0
# set betaKinity 0
# } else {
# set omega1 $omega
# set omega2 $omega_y
# set ksi1 $ksi
# set ksi2 $ksi_y
# set alphaMx [expr 2.0*$omega1*$omega2*($ksi1*$omega2-$ksi2*$omega1)/($omega2*$omega2-$omega1*$omega1)]
# set alphaMy [expr 2.0*$omega1*$omega2*($ksi1*$omega2-$ksi2*$omega1)/($omega2*$omega2-$omega1*$omega1)]
# set betaKinitx [expr 2.0*($ksi2*$omega2-$ksi1*$omega1)/($omega2*$omega2-$omega1*$omega1)]
# set betaKinity [expr 2.0*($ksi2*$omega2-$ksi1*$omega1)/($omega2*$omega2-$omega1*$omega1)]
# }
# }


# tangent stiffness proportional damping; +beatK*KCurrent
set betaK 0. 
# last commited stiffness RAYLEIGH damping parameter; +betaKcomm*KlastCommitt
set betaKcomm 0.

# rayleigh $alphaMx $betaK $betaKinitx $betaKcomm

region 1 -node 1 2 -rayleigh $alphaMx $betaK $betaKinitx $betaKcomm
region 2 -node 3 4 -rayleigh $alphaMy $betaK $betaKinity $betaKcomm
# region 1 -Element 1  -rayleigh $alphaMx $betaK $betaKinitx $betaKcomm
# region 2 -Element 2 -rayleigh $alphaMy $betaK $betaKinity $betaKcomm

puts "rayleigh_X $alphaMx $betaK $betaKinitx $betaKcomm"
puts "rayleigh_Y $alphaMy $betaK $betaKinity $betaKcomm"

constraints Plain
numberer RCM
test NormDispIncr 1.0e-8 20
system BandSPD
#system ProfileSPD
algorithm Newton
integrator Newmark 0.5 0.25

puts [pwd]

# Time to run some timehistory analysis.
# 
if {$analysistype=="dynamic"} {
  source [concat [pwd]/util/DefineXYZ_UniformExcitation.tcl]
  # you are getting back "nptsx" and "dtx"
  DefineXYZ_UniformExcitation $dtsub $g $GMdir $GMfileX $GMfileY $GMfileZ $GMfactorX $GMfactorY $GMfactorZ nptsx dtx
  recorder Node -file NodeAbs.out -timeSeries 1 -time -node 2 -dof 1 accel
  # Common running parameters for both forcing functions
  integrator Newmark 0.5 0.25
  test NormDispIncr 1.0e-8 10 0
  puts "analysis Transient"
  source [concat [pwd]/util/RunTransient2Converge.tcl]
  analysis Transient
   
   puts nptsx=$nptsx
   puts dtsub=$dtsub
   set outfile [open [concat [pwd]/Npoints.out]  "w"]
   puts $outfile $nptsx
   close $outfile	
  RunTransient2Converge [expr $nptsx*$dtsub] [expr $dtx/$dtsub]
  
 
} elseif {$analysistype=="pushover"} {
  source ../util/RunPushover2Converge.tcl
    pattern Plain 2 Linear {
      load 2 1
    }
  
  set IDctrlNode 2
  
  #
  set Nsteps 700
  set DmaxPush [expr $Nsteps*$DispStep]
  puts "Pushing to [expr $Nsteps*$DispStep]m in $Nsteps steps"
  puts "CAREFUL NEGATIVE SLOPES WILL CAUSE A FAILURE TO CONVERGE"
  integrator DisplacementControl $IDctrlNode 1 $DispStep
  
  test NormDispIncr 1.0e-8 50 0
  analysis Static
  RunPushover2Converge  $IDctrlNode $DmaxPush $Nsteps 1  
  #analyze $Nsteps
  loadConst -time 0.0
} elseif {$analysistype=="RCycD"} {
  source [concat [pwd]/peakpts_.tcl]
  # since this is performed under displacement-control, we need a reference load
  pattern Plain 2 Linear {
    load 2 1 0 0
	load 4 0 1 0
   }
  test NormDispIncr 1.0e-8 20
  algorithm Newton
  source [concat [pwd]/util/RunPushover2Converge.tcl]
  source [concat [pwd]/util/procRCycDAns2.tcl]
  puts "Loading Protocol: $peakpts"
  puts "Performing Reverse Cyclic Displacement Analysis"
  set increments 100
  set nodeTag 2
  set dofTag 1
  ## start procedure for feeding in Reverse Cyclic loading to the model by Disp. control
  procRCycDAns2 $increments $nodeTag $dofTag $peakpts
} elseif {$analysistype=="eigenvalue"} {
  set outfile [open "SDOFModelPeriods.out" "w"]
  puts $outfile $Tperiod
  close $outfile
} elseif {$analysistype=="D2SPO"} {

  source C:/Users/qwerty/Dropbox/me/Vamvatsikos_SDOF_dyn_spo/osees/util/DefineXYZ_UniformExcitation.tcl
  # you are getting back "nptsx" and "dtx"
  DefineXYZ_UniformExcitation $dtsub $g $GMdir $GMfileX $GMfileY $GMfileZ $GMfactorX $GMfactorY $GMfactorZ nptsx dtx
  recorder Node -file NodeAbs.out -timeSeries 1 -time -node 2 -dof 1 accel
  # Common running parameters for both forcing functions
  integrator Newmark 0.5 0.25
  test NormDispIncr 1.0e-8 10 0
  puts "analysis Transient"
  source ../util/RunTransient2Converge.tcl
  analysis Transient
   
   puts nptsx=$nptsx
   puts dtsub=$dtsub
	set outfile [open "Npoints.out"  "w"]
    puts $outfile $nptsx
    close $outfile	
  RunTransient2Converge [expr $nptsx*$dtsub] [expr $dtx/$dtsub]
   # loadConst -time 0.0
	

   puts "ADDING PARALLEL SPRING FOR PUSHOVER"
   puts "IF NON-CONVERGENCE OCCURS, INCREASE ITS STIFFNESS!"
   uniaxialMaterial Elastic 102 [expr 50*$kx] 0.0
   node 3 0
   node 4 0
   element zeroLength 2 3 4 -mat 102 -dir 1
   # slave node 4 to node 2
   equalDOF 2 4 1 
   fix 3 1
	

	  # Fai pushover dopo analisi dinamica
   source ../util/RunPushover2Converge.tcl
    pattern Plain 2 Linear {
      load 2 1 
    }
  
  set IDctrlNode 2
  
  #
  set Nsteps 1000
  set DmaxPush [expr $Nsteps*$DispStep]
  puts "Pushing to [expr $Nsteps*$DispStep]m in $Nsteps steps"
  puts "CAREFUL NEGATIVE SLOPES WILL CAUSE A FAILURE TO CONVERGE"
   
  integrator DisplacementControl $IDctrlNode 1 -$DispStep 
  #loadConst -time 0.0 
  
  test NormDispIncr 1.0e-8 70 0
  analysis Static
  RunPushover2Converge  $IDctrlNode $DmaxPush $Nsteps 1 1 
  # analyze $Nsteps
  loadConst -time 0.0
} elseif {$analysistype=="D2IDA"} {

    # ANALISI DINAMICA
	# you are getting back "nptsx" and "dtx"
	  source MatDYN_thfile.tcl
	  source ../util/DefineXYZ_UniformExcitation_DYNONLY.tcl
	  
      # you are getting back "nptsx" and "dtx"
    DefineXYZ_UniformExcitation_DYNONLY $dtsub $g $GMdir_dyn $GMfileX_dyn $GMfileY_dyn $GMfileZ_dyn $GMfactorX_dyn $GMfactorY_dyn $GMfactorZ_dyn nptsx2 dtx2
	#recorder Node -file NodeAbs.out -timeSeries 1 -time -node 2 -dof 1 accel
	# Common running parameters for both forcing functions
	integrator Newmark 0.5 0.25
	test NormDispIncr 1.0e-8 10 0
	puts "analysis Transient"
	source ../util/RunTransient2Converge.tcl
	analysis Transient

	# puts nptsx=$nptsx
	# puts dtsub=$dtsub
	set outfile [open "Npoints.out"  "w"]
	puts $outfile $nptsx2
	close $outfile	
	RunTransient2Converge [expr $nptsx2*$dtsub] [expr $dtx2/$dtsub]
	 loadConst -time 0.0
	
	    # ANALISI DINAMICA INCREMENTALE
	puts "run IDA"
    source ../util/DefineXYZ_UniformExcitation.tcl	
	# you are getting back "nptsx" and "dtx"
	DefineXYZ_UniformExcitation $dtsub $g $GMdir $GMfileX $GMfileY $GMfileZ $GMfactorX $GMfactorY $GMfactorZ nptsx dtx
	recorder Node -file NodeAbs.out -timeSeries 1 -time -node 2 -dof 1 accel
	# Common running parameters for both forcing functions
	integrator Newmark 0.5 0.25
	test NormDispIncr 1.0e-8 10 0
	puts "analysis Transient"
	source ../util/RunTransient2Converge.tcl
	analysis Transient

	puts nptsx=$nptsx
	puts dtsub=$dtsub
	# set outfile [open "Npoints.out"  "w"]
	# puts $outfile $nptsx
	# close $outfile	
	RunTransient2Converge [expr $nptsx*$dtsub] [expr $dtx/$dtsub]
	loadConst -time 0.0
}



#if {!$runIDAflag} {
  file delete SDOFModelPrint.out
  print SDOFModelPrint.out
#}
