function [drift,tout]=postproc_osees1Di_oscillator_B2B;
% Function for postprocessing 1D oscillators (e.g. simpleSDOF3.tcl) when running IDA
% with opensees. 
% It has been designed to be called from within anlsproc_oseesNDi.m to do the 
% post processing after each single dynamic run has been performed. 
%________________________________________________________________________________
% INPUT
%
% OUTPUT
% drift        : the primary EDP that will be output to traceIDA.m
%                This is used by traceIDA to measure against Th_drift limit.
%                If it exceeds Th_drift, then the algorithm stops incrementing 
%                the IM.
% tout         : a structure containing all the output taken from the timehistories
%                for the sdof, there is actually nothing here! But I could
%                use velocities or accelerations if I wanted.
%_____________________________________________________________________________________
%
% NOTE: the recorders must also output time, as we are reading the 2nd
%       column in each file!
%
% Created Feb 26,2006: The file postproc_osees2Di_frame.m was used as
%                       a template. It has been updated as well, so that 
%                       it doesn't produce errors if "-time" is specified
%                       or not at the recorders!
% Updated 10/05/2006: Returns an empty structure, instead of a non-empty
%                     one with useless stuff!
% Updated 08/01/2012: Made compatible with newer output of OpenSEES which omits the 
%                     final space at the end of each line, thus removing the need to 
%                     decrease icol by 1.


% Numero di punti per ogni record:
% Numero di punti record per analisi dinamica:
load([pwd,'/','Npoints_b2b_dyn_or.out']);
% Numero di punti record per analisi dinamica con aggiunta coda:
load([pwd,'/','Npoints_b2b.out']);
% Numero di punti record per analisi dinamica incrementale:
load([pwd,'/','Npoints_or_b2b.out']);
% Numero di punti record per analisi dinamica incrementale con aggiunta coda:
load([pwd,'/','Npoints_ida_b2b.out']);
% Numero di punti da aggiungere al record per analisi dinamica
N_extra_run_res_dyn=round((Npoints_b2b-Npoints_b2b_dyn_or)/2);
% Numero di punti da aggiungere al record per analisi dinamica incrementale
N_extra_run_res=round((Npoints_ida_b2b-Npoints_or_b2b)/2);
single_rdrx_file=dir([pwd,'/','Disp.out']);

if ~isempty(single_rdrx_file)
    tdrx=dlmread([pwd,'/',single_rdrx_file.name],' ');
    tdrx_tot=tdrx;
    tdrx_dyn=tdrx(1:Npoints_b2b,:);
    tdrx_ida=tdrx(Npoints_b2b+1:end,:);
    %icol=size(tdrx,2)-1;   
    icol=size(tdrx,2);   
    maxrdrx=max(abs(tdrx_ida(:,icol)));
    %maxrdrx=max(abs(tdrx_tot(:,icol)));
    aa=(tdrx_ida(:,icol));
%     res_x=aa(end);
    res_x=mean(aa((Npoints_or_b2b+N_extra_run_res):Npoints_ida_b2b));
    bb=(tdrx_dyn(:,icol));
%     res_dyn=bb(end);
    res_x_dyn=mean(bb((Npoints_b2b_dyn_or+N_extra_run_res_dyn):Npoints_b2b));
    maxrdrx_dyn=max(abs(tdrx_dyn(:,icol)));
end
% load('Force.out');
% figure; plot(-tdrx_dyn(:,2),Force(1:Npoints,2),'r')
% hold on
% plot(-tdrx_ida(:,2),Force(Npoints+1:end,2),'k')
% figure; plot(tdrx_dyn(:,1),tdrx_dyn(:,2),'r')
% hold on
%  plot((tdrx_dyn(end,1)+tdrx_ida(2:end,1)),tdrx_ida(2:end,2),'y')
drift=maxrdrx;
drift_dyn=maxrdrx_dyn;
%  tout=struct([]);
tout.maxrdrx=maxrdrx;
tout.maxrdrx_dyn=maxrdrx_dyn;
tout.res_x=res_x;% tout.res=res;
tout.res_dyn=res_x_dyn;% tout.res=res;