function [anlsout]=trans2ida_osees(transout,maxrec)
% This routine is called at the end of every runIDA_.... procedure or
% function I am using that calls Opensees.
%
% Now collect all the results from transout into some cohesive variables
% The second run is always there as it is the elastic one! But be careful, 
% you never know.
% 
%readout(2)=transout{2};
%for i=1:maxrec
%end
%-------------------------------------------
% this will do what trans2ida would normally do!
%
% NOTE: Transout is a cell array Nrec x Nruns.
% Each entry in the cell is a structure, with fields named as the variables
% that will come out in the end. Each of the fields is either a single number
% a vector, or a cell vector. Correspondingly, the output variable
% becomes a vector, a 2D array or a 2D cell array
%
%-----------------------------------------------
% The second run is always the elastic one, so use it!
% It has the correct dimensions!
%
% NOTE: It is not obvious, but even if transout is a proper cell array of empty
% structures, this routine handles it very well. In the end, anlsout comes
% as a "0x0 struct array with no fields". Perfect!
%
% Created, 29/Nov/04
% Updated, 09/Oct/05: Added the ability to process cell arrays as
%                         well.
% 


fields=fieldnames(transout{1}{2});
anlsout=transout{1}{2};
   
for R=1:maxrec
   % pick each field separately
   for j=1:length(fields)
      % assign a tmpfield array for each field-name. The size is 
      %   (number of vector elements) x (number of runs) 
      if isnumeric(transout{R}{2}.(fields{j}))
         tmpfield=zeros(length(transout{R}{2}.(fields{j})),length(transout{R}));
      elseif iscell(transout{R}{2}.(fields{j}))
         tmpfield=cell(length(transout{R}{2}.(fields{j})),length(transout{R}));
      else 	
         error('trans2ida can only handle cells and vectors!')
      end
      % now do each run separately
      % the first index is #record, the second is #run.
      for i=1:length(transout{R})
         if ~isempty(transout{R}{i})
            % better make another loop over the fieldnames (or fields of ID)
            % and store them in a new cell
            tmpfield(:,i)=getfield(transout{R}{i},fields{j})'; 
         else
            % better to force the empty/NaN assignment in the postprocessor
            % not here! 
            % The second run is always the elastic one, so use it!
            % It has the correct dimensions!
            if isnumeric(tmpfield)
              tmpfield(:,i)=getfield(transout{R}{2},fields{j})'*NaN;
            else
              tmpfield(:,i)={NaN};
            end
         end
      end
      %keyboard
      %setfield(anlsout,{R},fields{j},tmpfield);
      %anlsout
      eval(['anlsout(R).' fields{j} '= tmpfield;'])
   end
end
