function [drift,tout]=postproc_osees1Di_oscillator_IDA_2dir;
% Function for postprocessing 1D oscillators (e.g. simpleSDOF3.tcl) when running IDA
% with opensees. 
% It has been designed to be called from within anlsproc_oseesNDi.m to do the 
% post processing after each single dynamic run has been performed. 
%________________________________________________________________________________
% INPUT
%
% OUTPUT
% drift        : the primary EDP that will be output to traceIDA.m
%                This is used by traceIDA to measure against Th_drift limit.
%                If it exceeds Th_drift, then the algorithm stops incrementing 
%                the IM.
% tout         : a structure containing all the output taken from the timehistories
%                for the sdof, there is actually nothing here! But I could
%                use velocities or accelerations if I wanted.
%_____________________________________________________________________________________
%
% NOTE: the recorders must also output time, as we are reading the 2nd
%       column in each file!
%
% Created Feb 26,2006: The file postproc_osees2Di_frame.m was used as
%                       a template. It has been updated as well, so that 
%                       it doesn't produce errors if "-time" is specified
%                       or not at the recorders!
% Updated 10/05/2006: Returns an empty structure, instead of a non-empty
%                     one with useless stuff!
% Updated 08/01/2012: Made compatible with newer output of OpenSEES which omits the 
%                     final space at the end of each line, thus removing the need to 
%                     decrease icol by 1.


single_rdrx_file=dir([pwd,'/','Disp.out']);


if ~isempty(single_rdrx_file)
   tdrx=dlmread([pwd,'/',single_rdrx_file.name],' ');
   %icol=size(tdrx,2)-1;   
   icol=2;   
   % Massimo spostamento in direzione x
   [~,ind]=max(abs(tdrx(:,icol)));
   % Conserva la direzione dove il massimo  occorso
   maxrdrx=tdrx(ind(1),icol);
   aa=((tdrx(:,icol)));
   % residuo dir x:
   res_x=aa(end);
   icol=5;   
   % Massimo spostamento in direzione y
   [~,ind]=max(abs(tdrx(:,icol)));
   maxrdry=tdrx(ind(1),icol);
   % Residuo dir. y
   aa=((tdrx(:,icol)));
   res_y=aa(end);
   % Massimo nelle 2 direzioni
   maxrdr=max(abs(maxrdrx),abs(maxrdry));
   % Massimo combinazione quadratica:
   maxrdr_combquad=max(abs(sqrt(tdrx(:,3).^2+tdrx(:,2).^2)));
   % Massimo residuo nelle 2 direzioni
   maxres=max(res_x,res_y);
   % Massimo combinazione quadratica tra residui:
   maxres_combquad=max(abs(res_x^2+res_y^2));
  % Questa scelta  da migliorare, il senso  che se non lancio una MSA
  % allora vanno presi i valori assoluti degli EDP
  % L'unico setappdata che uso oltre a quello per handles_main  il seguente:
  flag_for_msa=getappdata(0,'flag_for_msa')
   if isempty(flag_for_msa)
           maxrdrx=abs(maxrdrx);
           res_x=abs(res_x);
           maxrdry=abs(maxrdry);
           res_y=abs(res_y);
   end
end
%  figure;plot(tdrx(:,1),tdrx(:,2),'y')
%  figure;plot(tdrx(:,1),tdrx(:,3),'r')
drift=abs(maxrdrx);
% drifty=maxrdry;
tout.drifty=maxrdry;
tout.driftx=maxrdrx;
tout.drift=maxrdr;
tout.drift_quad=maxrdr_combquad;
tout.res_x=res_x;
tout.res_y=res_y;
tout.res_max=maxres;
tout.res_quad=maxres_combquad;