function [drift,tout]=postproc_osees2Di_frame
% Function for postprocessing 2D frames (e.g. RC5story) when running IDA
% with opensees. 
% It has been designed to be called from within anlsproc_oseesNDi.m to do the 
% post processing after each single dynamic run has been performed. 
%________________________________________________________________________________
% INPUT
%
% OUTPUT
% drift            : the primary EDP that will be output to traceIDA.m
%                    This is used by traceIDA to measure against Th_drift limit.
%                    If it exceeds Th_drift, then the algorithm stops incrementing the IM.
%                    The EDP type can be selected by col_or_bear_flag.
% tout             : a structure containing all the output taken from the timehistories
%_____________________________________________________________________________________
%
%
% Created Sep 22,2005: The file postproc_osees3Di_bridge.m was used as
%         a template! It has been updated as well, so that it doesn't
%         produce errors if "-time" is specified or not at the recorders!
% Updated 05/Oct/2010: Now OpenSees 2.2 does not produce the extra space at
%         the end of each output line. So you do not need the -1 when
%         defining icol below.

all_idrx_files =dir('idr_*x.out');
%If the files are named idr_01x, idr_02x (instead of idr_1x and idr2x) 
% then they will be sorted in the right order as columns increase (left to right)!
for i=1:length(all_idrx_files)
   tdrx=dlmread(all_idrx_files(i).name,' ');
   % use this trick to make sure you are reading the right column,
   % regardless of whether the output contains a time-column or not
   icol=size(tdrx,2);
   maxidr_mx(i)=max(abs(tdrx(:,icol)));
end

single_rdrx_file=dir('roofdrx.out');
if ~isempty(single_rdrx_file)
   tdrx=dlmread(single_rdrx_file.name,' ');
   icol=size(tdrx,2);   
   maxrdrx=max(abs(tdrx(:,icol)));
end

drift=max(maxrdrx);
% drift_IDR=max(maxidr_mx);

% Now try to make them into structures. Seems more natural and can still
% be handled like a vector at the top level, just as traceIDA needs!
tout.maxidr_mx=maxidr_mx;
tout.maxrdrx=maxrdrx;
