%------------------------------------------------------------
% Elastic response specra (D,PSV,PSA), Newmark integration. 
%------------------------------------------------------------

% INPUT:
% dt:     Time Interval (Sampling Time) of Record
% Acc:    Ground Motion Acceleration in g 
% zeta:   Damping Ratio in percent (%); e.g. 5
% g:      acceleration of gravity, default 9.81 m/s^2
% T:      Period of natural vibration (sec)

% OUTPUT:

% Spa:    Spectral Pseudo-aceleration
% Spv:    Spectral Pseudo-velocity
% Sd:     Spectral Displacement

function [Spa,Spv,Sd]=spectra_light(dt,Acc,zeta,g,T)
if T~=0
    u=zeros(length(Acc),1);
    v=zeros(length(Acc),1);
    ac=zeros(length(Acc),1);
    Acc(end+1)=0;
        omega=2*pi/T;      
        m=1;       
        k=(omega)^2*m;
        c=2*m*omega*zeta/100;
        K=k+3*c/dt+6*m/(dt)^2;
        a=6*m/dt+3*c;
        b=3*m+dt*c/2;    
      for i=1:length(u)-1
         u(1,1)=0;                      
         v(1,1)=0;
         ac(1,1)=0;    
         df=-(Acc(i+1)-Acc(i))+a*v(i,1)+b*ac(i,1);  
         du=df/K;
         dv=3*du/dt-3*v(i,1)-dt*ac(i,1)/2;
         dac=6*(du-dt*v(i,1))/(dt)^2-3*ac(i,1);
         u(i+1,1)=u(i,1)+du;
         v(i+1,1)=v(i,1)+dv;
         ac(i+1,1)=ac(i,1)+dac;

      end
        Sd=max(abs((u(:,1))));
        Spv=Sd*omega;
        Spa=Sd*(omega)^2/g;
else
    Sd=0; Spv=0;Spa=max(abs(Acc))/g;
end




